; LCD26x13, 28.10.10, Harald Peters 
; Ansteuerung 320x240 LCD 13 Zeilen Text mit je 26 Zeichen (12x16 Zeichensatz) 
; oder                    10 Zeilen Text mit je 20 Zeichen (16x24 Zeichensatz)
; Empfang der Zeichen ber Uart oder I2C-Bus
// Mega88: FuseBitsE: statt F9h FCh (512Byte Bootloader PD0/PD1)
// Mega88, FuseBitsH: statt DFh D4h (JTAG disable+EE nicht lschen+BOD)
// Mega88, FuseBitsL: statt 62h CFh (16MHz, Quarz, 1:1)

.include "m88def.inc"

;Im Interrupt genutzte und genderte Register:
.def regsave    =r2
.def clockL     =r3
.def clockH     =r4
.def X_Cnt      =r5
.def CursorSave =r6
.def blinkcount =r7
.def invsel     =r8
.def YSaveL     =r10
.def YSaveH     =r11
.def WPos       =r12
.def RPos       =r13
.def XSaveL     =r14
.def XSaveH     =r15
.def tempi      =r16
.def tempi2     =r17
.def Y_Cnt      =r18
.def C_Cnt      =r19
.def flags      =r23
;zustzlich: X und Z

;Sonstige Register:
.def temp       =r20
.def temp2      =r21
.def RX         =r22
;zustzlich: Y

.equ CURSOR     =0
.equ DOBLINK    =1
.equ MEMIDLE    =2
.equ BLINKSTATE =3
.equ BLINKCURSOR=4

;PortB
.equ    CLOCK   =0                  ; Pixelclock
.equ    PWM     =1                  ; PWM fr Contrast
.equ    LP      =2                  ; Latch Puls (HSync)
.equ    FRAME   =3                  ; First Line Marker (VSync)
.equ    M       =4                  ; AC Drive
.equ    ONOFF   =5                  ; LCD (VLCD) Enable

;Werte
.equ Framerate  =68                 ; Refreshrate
.equ F_CPU      =16000000           ; CPU Freq
.equ RX_Buffer  =32                 ; UART Buffer
.equ CURSOR_CHAR=0x5F               ; ASCII Zeichen das als Cursor verwendet wird
.equ BlinkFreq  =221                ; Blinkfrequenz (0-255) 

; Interne Konstanten
.equ HFREQ      =Framerate*240
.equ TDIV       =((F_CPU/8+(HFREQ)/2)/HFREQ)
.equ CSize      =18 ; 12
.equ XSize      =27 ; 40            ; nur 26Zeichen vollstndig, 27, damit kein Rest am rechten Rand
;.equ CSize      =12 ; 12
;.equ XSize      =40 ; 40
.equ YSize      =240/CSize

.equ Input = 3 ; 1: Uart, 2: TWI

.if (Input&2)
; TWI SLAVE EINSTELLUNGEN
.equ TWI_SLAVE_ADRESSE      =  0x10 ; eigene SLAVE ADRESSE 2...126; geradzahlig          
; TWI Slave Receiver Codes
.equ TW_SR_SLA_ACK          = 0x60; x60 01100000 (SLA+W wurde empfangen-ACK wurde zurckgesendet)                                                   
.equ TW_SR_ARB_LOST_SLA_ACK = 0x68; x68 01101000 (Arbitration verloren in SLA+R/W als MASTER;  SLA+W wurde empfangen;  ACK wurde zurckgesendet     
.equ TW_SR_GCALL_ACK        = 0x70; x70 01110000 (General call address wurde empfangen;  ACK wurde zurckgesendet                                   
.equ TW_SR_ARB_LOST_GCALL_ACK=0x78; x78 01111000 (Arbitration verloren in SLA+R/W als MASTER;General call address wurde empfangen; ACK wurde zurckgesendet
.equ TW_SR_DATA_ACK         = 0x80; x80 10000000 (die vorher adressierten (SLA+W) Daten wurden empfangen;  ACK wurde zurckgesendet                 
.equ TW_SR_DATA_NACK        = 0x88; x88 10001000 (die vorher adressierten (SLA+W) Daten wurden empfangen; ACK wurde nicht zurckgesedet             
.equ TW_SR_GCALL_DATA_ACK   = 0x90; x90 10010000 (die vorher adressierten (General call) Daten wurden empfangen;  ACK wurde zurckgesendet          
.equ TW_SR_GCALL_DATA_NACK  = 0x98; x98 10011000 (die vorher adressierten (General call) Daten wurden empfangen;  ACK wurde nicht zurckgesendet    
.equ TW_SR_STOP             = 0xA0; xA0 10100000 (STOP wurde empfangen, oder wiederholter Start)                                                    
; TWI Slave Transmitter Codes
.equ TW_ST_SLA_ACK          = 0xA8; xA8 10101000 (SLA+R wurde empfangen; ACK wurde zurckgesendet)                                              
.equ TW_ST_ARB_LOST_SLA_ACK = 0xB0; xB0 10110000 (Arbitration verlor SLA+R/W als MASTER, ACK wurde zurckgesendet)                              
.equ TW_ST_DATA_ACK         = 0xB8; xB8 10111000 (TWDR ist bertragen worden;  ACK ist empfangen worden                                         
.equ TW_ST_DATA_NACK        = 0xC0; xC0 11000000 (TWDR ist bertragen worden;  ACK ist NICHT empfangen worden                                   
.equ TW_ST_LAST_DATA        = 0xC8; xC8 11001000 (Letztes Datenbyte in TWDR ist bertragen worden (TWEA = "0");  Ack ist empfangen worden       
.equ TW_NO_INFO             = 0xF8; xF8 11111000 (Keine relevanten Zustandinformationen vorhanden;  TWINT = "0" keine TWDR-Ttigkeit            
.equ TW_BUS_ERROR           = 0x00; x00 00000000 (Bus-Error wegen ungltige STARToder STOP BEDIgung; keine TWDR-Ttigkeit                       
.endif

.dseg
DDRAM:  .byte   XSize*YSize         ; DDRAM, Gre 40x20=800, 13x26=338 bzw 20x10=200
RXBUF:  .byte   RX_Buffer           ; RX Buffer
invtab: .byte   YSize               ; Invert select

;****************************************************************************
;   Interrupt Vektoren
;****************************************************************************

.cseg
.org 0
rjmp Reset

.org OC2Aaddr
rjmp LCD_Line

.org URXCaddr
rjmp UART_RX_int

.org TWIaddr    
rjmp TWI_RX_int ; hier I2C


;****************************************************************************
;   CPU Register Initialisierung
;****************************************************************************

Reset:
    ldi temp, low(RAMEND)
    out SPL, temp                   ;setup stack pointer
    ldi temp, high(RAMEND)
    out SPH, temp                   ;setup stack pointer

    ldi temp, 0x0F      ; PC4,5 fr I2C
    out DDRC, temp
    ser temp            ; temp = 0xFF
    out PORTC, temp
    out DDRB, temp
    out PORTD, temp
    ldi temp,(1<<PD2)
    out DDRD, temp
    cbi PORTD, (PD2)


    ldi temp, TDIV-1
    sts OCR2A, temp

    ldi temp, (1<<WGM10)|(1<<COM1A1)|(1<<COM1A0); 8bit PWM
    sts TCCR1A, temp

    ldi temp, 1                     ; 62,5kHz PWM
    sts TCCR1B, temp

    ldi temp, 128
    sts OCR1AL, temp

    ldi temp, (1<<WGM10)            ; CTC
    sts TCCR2A, temp

    ldi temp, (1<<CS21)             ; 1:8
    sts TCCR2B, temp

    ldi temp, (1<<OCIE2A)           ; Compare2A Interrupt: Beginn der Datenausgabe
    sts TIMSK2, temp

.if (Input&1)
	ldi temp, 1<<PD0 ; PullUp PD0=RxD
	sts PORTD, temp
	ldi temp, 34 ; Baudrate 57600
	sts UBRR0L, temp
	ldi temp, (1<<U2X0)	;Verdoppeln
	sts UCSR0A, temp 		
	ldi temp, (1<<RXEN0)|(1<<RXCIE0)	; RX aktivieren
	sts UCSR0B, temp 		
.endif
.if (Input&2)
    rcall  TWI_INI
.endif

;****************************************************************************
;   Variablen Initialisierung
;****************************************************************************

    clr RPos
    clr WPos
    clr flags

    ldi YL, low(invtab)
    ldi YH, high(invtab)

    ldi temp, 0
    clrloopi:
        st Y+, temp
        ldi temp2, high(YSize+invtab)
        cpi YL, low(YSize+invtab)
        cpc YH, temp2
        brne clrloopi


    ldi YL, low(DDRAM)
    ldi YH, high(DDRAM)

    ldi temp, 32
    clrloop:
        st Y+, temp
        ldi temp2, high(XSize*YSize+DDRAM)
        cpi YL, low(XSize*YSize+DDRAM)
        cpc YH, temp2
        brne clrloop
; hier 24		
.if (CSize==12)
    ldi YL, low(DDRAM+165)
    ldi YH, high(DDRAM+165)
    ldi temp, 201
    st Y+, temp
    ldi temp, 205
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    ldi temp, 187
    st Y+, temp

    ldi YL, low(DDRAM+205)
    ldi YH, high(DDRAM+205)
    ldi temp, 186
    st Y+, temp
    ldi YL, low(DDRAM+234)
    ldi YH, high(DDRAM+234)
    st Y+, temp

    ldi YL, low(DDRAM+245)
    ldi YH, high(DDRAM+245)
    st Y+, temp
    ldi YL, low(DDRAM+274)
    ldi YH, high(DDRAM+274)
    st Y+, temp

    ldi YL, low(DDRAM+285)
    ldi YH, high(DDRAM+285)
    st Y+, temp
    ldi YL, low(DDRAM+314)
    ldi YH, high(DDRAM+314)
    st Y+, temp

    ldi YL, low(DDRAM+325)
    ldi YH, high(DDRAM+325)
    st Y+, temp
    ldi YL, low(DDRAM+354)
    ldi YH, high(DDRAM+354)
    st Y+, temp

    ldi YL, low(DDRAM+365)
    ldi YH, high(DDRAM+365)
    st Y+, temp
    ldi YL, low(DDRAM+394)
    ldi YH, high(DDRAM+394)
    st Y+, temp

    ldi YL, low(DDRAM+405)
    ldi YH, high(DDRAM+405)
    st Y+, temp
    ldi YL, low(DDRAM+434)
    ldi YH, high(DDRAM+434)
    st Y+, temp

    ldi YL, low(DDRAM+445)
    ldi YH, high(DDRAM+445)
    st Y+, temp
    ldi YL, low(DDRAM+474)
    ldi YH, high(DDRAM+474)
    st Y+, temp

    ldi YL, low(DDRAM+485)
    ldi YH, high(DDRAM+485)
    st Y+, temp
    ldi YL, low(DDRAM+514)
    ldi YH, high(DDRAM+514)
    st Y+, temp

    ldi YL, low(DDRAM+525)
    ldi YH, high(DDRAM+525)
    ldi temp, 200
    st Y+, temp
    ldi temp, 205
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    st Y+, temp
    ldi temp, 188
    st Y+, temp

    ldi YL, low(DDRAM+249)
    ldi YH, high(DDRAM+249)
    ldi temp, '3'
    st Y+, temp
    ldi temp, '2'
    st Y+, temp
    ldi temp, '0'
    st Y+, temp
    ldi temp, 'x'
    st Y+, temp
    ldi temp, '2'
    st Y+, temp
    ldi temp, '4'
    st Y+, temp
    ldi temp, '0'
    st Y+, temp
    ldi temp, ' '
    st Y+, temp
    ldi temp, 'L'
    st Y+, temp
    ldi temp, 'C'
    st Y+, temp
    ldi temp, 'D'
    st Y+, temp
    ldi temp, ' '
    st Y+, temp
    ldi temp, 'C'
    st Y+, temp
    ldi temp, 'o'
    st Y+, temp
    ldi temp, 'n'
    st Y+, temp
    ldi temp, 't'
    st Y+, temp
    ldi temp, 'r'
    st Y+, temp
    ldi temp, 'o'
    st Y+, temp
    ldi temp, 'l'
    st Y+, temp
    ldi temp, 'l'
    st Y+, temp
    ldi temp, 'e'
    st Y+, temp
    ldi temp, 'r'
    st Y+, temp

    ldi YL, low(DDRAM+334)
    ldi YH, high(DDRAM+334)
    ldi temp, '4'
    st Y+, temp
    ldi temp, '0'
    st Y+, temp
    ldi temp, 'x'
    st Y+, temp
    ldi temp, '2'
    st Y+, temp
    ldi temp, '0'
    st Y+, temp
    ldi temp, ' '
    st Y+, temp
    ldi temp, 'Z'
    st Y+, temp
    ldi temp, 'e'
    st Y+, temp
    ldi temp, 'i'
    st Y+, temp
    ldi temp, 'c'
    st Y+, temp
    ldi temp, 'h'
    st Y+, temp
    ldi temp, 'e'
    st Y+, temp
    ldi temp, 'n'
    st Y+, temp

    ldi YL, low(DDRAM+414)
    ldi YH, high(DDRAM+414)
    ldi temp, 184
    st Y+, temp
    ldi temp, ' '
    st Y+, temp
    ldi temp, 'b'
    st Y+, temp
    ldi temp, 'y'
    st Y+, temp
    ldi temp, ' '
    st Y+, temp
    ldi temp, 'H'
    st Y+, temp
    ldi temp, 'a'
    st Y+, temp
    ldi temp, 'r'
    st Y+, temp
    ldi temp, 'a'
    st Y+, temp
    ldi temp, 'l'
    st Y+, temp
    ldi temp, 'd'
    st Y+, temp

    ldi YL, low(DDRAM+496)
    ldi YH, high(DDRAM+496)
.endif

.if (CSize==24) || (CSize==18)
    ldi YL, low(DDRAM+XSize) ; 2. Zeile
    ldi YH, high(DDRAM+XSize)
    ldi temp, 'H'
    st Y+, temp
    ldi temp, 'a'
    st Y+, temp
    ldi temp, 'r'
    st Y+, temp
    ldi temp, 'a'
    st Y+, temp
    ldi temp, 'l'
    st Y+, temp
    ldi temp, 'd'
    st Y+, temp
    ldi temp, ' '
    st Y+, temp
    ldi temp, 'P'
    st Y+, temp
    ldi temp, 'e'
    st Y+, temp
    ldi temp, 't'
    st Y+, temp
    ldi temp, 'e'
    st Y+, temp
    ldi temp, 'r'
    st Y+, temp
    ldi temp, 's'
    st Y+, temp
.endif
;
;
    ldi XL, low(DDRAM)  ; X fr LCD_Line gebraucht
    ldi XH, high(DDRAM)
    MOVW XSaveL,XL      ; wird sofort in Int-Routine benutzt  

    sei
    sbi PORTB, ONOFF

wait_uart:          ; Begrungstext lschen wenn 1. Zeichen empfangen
    cp WPos, RPos
    breq wait_uart

    ldi temp, 32
    ldi YL, low(DDRAM)
    ldi YH, high(DDRAM)
clrloopw:
        st Y+, temp
        ldi temp2, high(XSize*YSize+DDRAM)
        cpi YL, low(XSize*YSize+DDRAM)
        cpc YH, temp2
        brne clrloopw

    ldi YL, low(DDRAM)
    ldi YH, high(DDRAM)

;****************************************************************************
;   Hauptprogramm
;****************************************************************************

Mainloop:
    rcall rxuart
    sbr flags, 1<<MEMIDLE
    rjmp Mainloop

rxuart:         ; UART Daten (hier von I2C) verarbeiten
    rcall uart_getchar
    cbr flags, 1<<MEMIDLE
    cpi RX, 32
    brlo command
    sbrc flags, CURSOR
    st Y, CursorSave
    st Y+, RX   ;Daten
    ldi temp, high(XSize*YSize+DDRAM)
    cpi YL, low(XSize*YSize+DDRAM)
    cpc YH, temp
    brlo skipwpreset
    ldi YL, low(DDRAM)
    ldi YH, high(DDRAM)
skipwpreset:
    sbrs flags, CURSOR
    ret
    ld CursorSave, Y
    ldi temp, CURSOR_CHAR
    st Y, temp
    ret


command:                ;Befehle
    cpi RX, 1           ;Home
    brne com1
    sbrc flags, CURSOR
    st Y, CursorSave
    ldi YL, low(DDRAM)
    ldi YH, high(DDRAM)
    sbrs flags, CURSOR
    ret
    ld CursorSave, Y
    ldi temp, CURSOR_CHAR
    st Y, temp
    ret
com1:
    cpi RX, 2           ;Display aus
    brne com2
    cbi PORTB, ONOFF
    ret
com2:
    cpi RX, 3           ;Display an
    brne com3
    sbi PORTB, ONOFF
    ret
com3:
    cpi RX, 4           ;Cursor aus
    brne com4
    sbrc flags, CURSOR
    st Y, CursorSave
    cbr flags, (1<<CURSOR)|(1<<BLINKCURSOR)
    ret
com4:
    cpi RX, 6           ;Cursor an
    brne com6
    sbrs flags, CURSOR
    ld CursorSave, Y
    sbr flags, 1<<CURSOR
    cbr flags, (1<<BLINKCURSOR)
    ldi temp, CURSOR_CHAR
    st Y, temp
    ret
com6:
    cpi RX, 7           ;Blinkender Cursor an
    brne com7
    sbrs flags, CURSOR
    ld CursorSave, Y
    sbr flags, (1<<CURSOR)|(1<<BLINKCURSOR)
    ldi temp, CURSOR_CHAR
    st Y, temp
    ret
com7:
    sbrc flags, CURSOR
    st Y, CursorSave
    cpi RX, 8           ;Backspace
    brne com8
    sbrc flags, CURSOR
    st Y, CursorSave
    subi YL, 1
    sbci YH, 0
    ldi temp, high(DDRAM)
    cpi YL, low(DDRAM)
    cpc YH, temp
    brsh exbs
    ldi YL, low(DDRAM)
    ldi YH, high(DDRAM)
exbs:
    ldi temp, 32
    st Y, temp
    sbrs flags, CURSOR
    ret
    ld CursorSave, Y
    ldi temp, CURSOR_CHAR
    st Y, temp
    ret
com8:
    cpi RX, 10          ;Line Feed
    brne com10
    sbrc flags, CURSOR
    st Y, CursorSave
    subi YL, low(-XSize)
    sbci YH, high(-XSize)
    ldi temp, high(XSize*YSize+DDRAM)
    cpi YL, low(XSize*YSize+DDRAM)
    cpc YH, temp
    brlo skipres
    ldi YL, low(DDRAM)
    ldi YH, high(DDRAM)
skipres:
    sbrs flags, CURSOR
    ret
    ld CursorSave, Y
    ldi temp, CURSOR_CHAR
    st Y, temp
    ret
com10:
    cpi RX, 11          ;Delete in place
    brne com11
    ldi temp, 32
    st Y, temp
    sbrs flags, CURSOR
    ret
    ldi temp,32
    mov CursorSave, temp
    ldi temp, CURSOR_CHAR
    st Y, temp
    ret
com11:
    cpi RX, 12          ;Clear all
    brne com12
    ldi YL, low(DDRAM)
    ldi YH, high(DDRAM)
    ldi temp, 32
    ldi temp2, high(XSize*YSize+DDRAM)
clrloop2:
    st Y+, temp
    cpi YL, low(XSize*YSize+DDRAM)
    cpc YH, temp2
    brne clrloop2
    ldi YL, low(DDRAM)
    ldi YH, high(DDRAM)
    sbrs flags, CURSOR
    ret
    ldi temp, 32
    mov CursorSave, temp
    ldi temp, CURSOR_CHAR
    st Y, temp
    ret
com12:
    cpi RX, 13          ; CR
    brne com14
    sbrc flags, CURSOR
    st Y, CursorSave
    ldi temp, low(XSize*(YSize-1)+DDRAM)    ; Anfang unterste Zeile
    ldi temp2, high(XSize*(YSize-1)+DDRAM)
crloop:
    cp YL, temp
    cpc YH, temp2
    brsh gotvalue       ; Position an erster Stelle der aktuellen Zeile gefunden
    subi temp, low(XSize)
    sbci temp2, high(XSize)
    rjmp crloop
gotvalue:
    mov YL, temp
    mov YH, temp2
    sbrs flags, CURSOR
    ret
    ld CursorSave, Y
    ldi temp, CURSOR_CHAR
    st Y, temp
    ret
com14:
    cpi RX, 14          ;Backlight
    brne com15
    in  temp, PORTD ; 20
    ldi temp2, (1<<PD2) ; 21
    eor temp, temp2
    out PORTD, temp ; 20


    rcall uart_getchar
    ret
com15:
    cpi RX, 15          ;Contrast
    brne com16
    rcall uart_getchar
    cpi RX, 101
    brlo skiplimc
    ldi RX, 100
skiplimc:
    mov temp, RX
    lsl RX
    lsr temp
    add RX, temp
    sts OCR1AL, RX
com16:
    cpi RX, 17          ;Set Cursor
    brne com17
    sbrc flags, CURSOR
    st Y, CursorSave
    rcall uart_getchar
    mov temp, RX
    rcall uart_getchar
    ldi temp2, XSize
    mul RX, temp2
    mov YH, r1
    mov YL, r0
    subi YL, low(-DDRAM)    ;Offset aufaddieren
    sbci YH, high(-DDRAM)
    add YL, temp            ;Spalte aufaddieren
    ldi temp, 0
    adc YH, temp
    ldi temp, high(XSize*YSize+DDRAM)
    cpi YL, low(XSize*YSize+DDRAM)
    cpc YH, temp
    brlo skiprs
    ldi YL, low(DDRAM)
    ldi YH, high(DDRAM)
skiprs:
    sbrs flags, CURSOR
    ret
    ld CursorSave, Y
    ldi temp, CURSOR_CHAR
    st Y, temp
    ret
com17:
    cpi RX, 30          ; Send direct
    brne com31
    sbrc flags, CURSOR
    st Y, CursorSave
    rcall uart_getchar
    rcall uart_getchar
    st Y+, RX       ;Daten
    ldi temp, high(XSize*YSize+DDRAM)
    cpi YL, low(XSize*YSize+DDRAM)
    cpc YH, temp
    brlo skipwpreset2
    ldi YL, low(DDRAM)
    ldi YH, high(DDRAM)
skipwpreset2:
    sbrs flags, CURSOR
    ret
    ld CursorSave, Y
    ldi temp, CURSOR_CHAR
    st Y, temp
    ret
com31:
    cpi RX, 31          ; invert select
    brne com32
    push YL
    push YH
    ldi YL, low(invtab)
    ldi YH, high(invtab)
    rcall uart_getchar
    cpi RX, YSize
    brlo skiplim31
    ldi RX, 0
skiplim31:
    add YL, RX
    clr RX
    adc YH, RX
    rcall uart_getchar
    st Y, RX
    pop YH
    pop YL
    ret
com32:
    ret

uart_getchar:
    cp WPos, RPos
    breq uart_getchar
    movw YSaveL, YL
    inc RPos
    mov RX, RPos
    andi RX, RX_Buffer-1
    mov RPos, RX
    clr RX
    ldi YL, low(RXBUF)
    ldi YH, high(RXBUF)
    add YL, RPos
    adc YH, RX
    ld RX, Y
    movw YL, YSaveL
    ret



hloopinv: ; Loop fr 1 Zeile, invertiert
        OUT       PORTB,clockL 
        LD        ZL,X+         
        LSL       ZL            
        LPM       tempi,Z+        
        COM       tempi           
; wenn CSize==18, dann hchstes HalbByte berspringen
.if (CSize==24)
        OUT       PORTB,clockH   
        OUT       PORTC,tempi 
        OUT       PORTB,clockL  
.endif       
        SWAP      tempi      
        OUT       PORTC,tempi   
        OUT       PORTB,clockH  
        NOP                     
        NOP                     
        OUT       PORTB,clockL  
        LPM       tempi,Z+      
        OUT       PORTB,clockH
        COM       tempi         
        OUT       PORTC,tempi   
        OUT       PORTB,clockL  
        SWAP      tempi           
        OUT       PORTC,tempi    
        OUT       PORTB,clockH 
        DEC       X_Cnt         
        BRNE       hloopinv   
	    out PORTB, clockL		; PCLK L
        RJMP       hloopend

; hier Int-Einsprung:
LCD_Line:
        IN        regsave,sreg
        LDI       tempi, XSize  ; n Zeich/Zeile
        MOV       X_Cnt,tempi 
        IN        tempi,PORTB  
        ANDI      tempi,0xFE    ; Bit 0  = 0
        MOV       clockL,tempi 
        ORI       tempi,0x01   
        MOV       clockH,tempi 
        MOVW      XL,XSaveL   
        TST       invsel           
        BRNE       hloopinv

hloop:        
        OUT       PORTB,clockL 
; ldt Inhalt von DDRAM[i] in Z
        LD        ZL,X+         ; startet mit X = DDRAM    
        LSL       ZL            ; links schieben = *2  
        LPM       tempi,Z+ 
; wenn CSize==18, dann hchstes HalbByte berspringen
.if (CSize==24)
        OUT       PORTB,clockH
        NOP                    
        OUT       PORTC,tempi 
        OUT       PORTB,clockL
.endif       
        SWAP      tempi 
        OUT       PORTC,tempi    
        OUT       PORTB,clockH  
        NOP                     
        NOP                      
        OUT       PORTB,clockL 
        LPM       tempi,Z       
        OUT       PORTB,clockH 
        NOP                    
        OUT       PORTC,tempi
        OUT       PORTB,clockL 
        SWAP      tempi        
        OUT       PORTC,tempi   
        OUT       PORTB,clockH   
        DEC       X_Cnt          
        BRNE       hloop       
        OUT       PORTB,clockL  
hloopend:
        SBI       PORTB,LP
        NOP                      
        NOP                      
        NOP                      
        CBI       PORTB,LP
        NOP                      
        DEC       C_Cnt            
        CBI       PORTB,FRAME
        BREQ       skipcloop      
        INC       ZH  
        SBIW      XL, XSize     ; X := X - XSize
        RJMP       exit_int

skipcloop: ; Alles fr neue Textzeile einrichten
        LDI       C_Cnt, CSize; hier 18; 24
        INC       Y_Cnt
        LDI       ZL, low(invtab)
        LDI       ZH, high(invtab)
        CLR       tempi  
        ADD       ZL,Y_Cnt
        ADC       ZH,tempi
        LDD       invsel,Z+0
        LDI       ZH, high(2*font)
        CPI       Y_Cnt, YSize
        BRNE       exit_int      
        SBIS      PORTB,M
        SBI       PORTB,M
        SBIC      PINB,M
        CBI       PORTB,M
        SBI       PORTB, FRAME
        CLR       Y_Cnt  
        LDI       XL, low(DDRAM)
        LDI       XH, high(DDRAM)
        LDS       invsel, invtab
        DEC       blinkcount
        BRNE       exit_int 
        LDI       tempi,0x22  ; 255-BlinkFreq
        MOV       blinkcount,tempi 
        ORI       flags,0x02  
;       sbr       flags, 1<<DOBLINK
exit_int:
        SBRS      flags,BLINKCURSOR
        RJMP       skipcursor
        SBRS      flags,DOBLINK 
        RJMP       skipcursor
        SBRS      flags,MEMIDLE
        RJMP        skipcursor
        ANDI      flags,0xFD   
        SBRS      flags,BLINKSTATE
        STD       Y+0,CursorSave
        LDI       tempi, CURSOR_CHAR
        SBRC      flags,BLINKSTATE
        STD       Y+0,tempi     
        LDI       tempi, 1<<BLINKSTATE
        EOR       flags,tempi      
skipcursor:
        MOVW      XSaveL,XL 
        OUT       sreg,regsave
        RETI                  

.if (Input&1); 2: UART
UART_RX_int:
	in regsave, sreg
	lds tempi, UDR0
	inc WPos
	mov tempi2, WPos
	andi tempi2, RX_Buffer-1
	cp tempi2, RPos
	breq ubuffer_full
	mov WPos, tempi2
	clr tempi2
	ldi XL, low(RXBUF)
	ldi XH, high(RXBUF)
	add XL, WPos
	adc XH, tempi2
	st X, tempi
ubuffer_full:
	out sreg, regsave
reti
.endif

.if (Input&2); 2: TWI

TWI_INI:
    ; TWI TWAR (nur SLAVE)  Adress-Register     
    ldi tempi,(TWI_SLAVE_ADRESSE)	; keine Reaktion auf General Call 
    sts TWAR,tempi
    ldi tempi, 1<<PC4|1<<PC5 ; PullUp PC4=SDA; PC5=SCL
    sts PORTC,tempi
    ; TWI TWCR              Control-REGISTER; I2C freigeben mit Interrupt   
    ldi tempi, 1<<TWINT|1<<TWEA|0<<TWSTA|0<<TWSTO|0<<TWWC|1<<TWEN|1<<TWIE
    sts TWCR,tempi
    ret
;------------------------------------------
; Interruptroutine, aufgerufen wenn I2C-nderung
TWI_RX_int:
    in regsave, sreg

    lds tempi, TWSR      ; Status-Register abfragen                      
    andi tempi, 0xF8     ; Bit0...2 ausblenden (Prescaler und Reserve-Bit)
    
    cpi tempi, TW_SR_SLA_ACK             ; x60   
    breq TWSI_TW_SR_SLA_ACK
    cpi tempi, TW_SR_ARB_LOST_SLA_ACK    ; x68   
    breq TWSI_TW_SR_ARB_LOST_SLA_ACK
    cpi tempi, TW_SR_GCALL_ACK           ; x70   
    breq TWSI_TW_SR_GCALL_ACK
    cpi tempi, TW_SR_ARB_LOST_GCALL_ACK  ; x78   
    breq TWSI_TW_SR_ARB_LOST_GCALL_ACK
    cpi tempi, TW_SR_DATA_ACK            ; x80   
    breq TWSI_TW_SR_DATA_ACK        
    cpi tempi, TW_SR_DATA_NACK           ; x88   
    breq TWSI_TW_SR_DATA_NACK
    cpi tempi, TW_SR_GCALL_DATA_ACK      ; x90   
    breq TWSI_TW_SR_GCALL_DATA_ACK   
    cpi tempi, TW_SR_GCALL_DATA_NACK     ; x98   
    breq TWSI_TW_SR_GCALL_DATA_NACK
    cpi tempi, TW_SR_STOP                ; xA0   
    breq TWSI_TW_SR_STOP            
;   
    cpi tempi, TW_ST_SLA_ACK             ; 0xA8  
    breq TWSI_TW_ST_SLA_ACK 
    cpi tempi, TW_ST_ARB_LOST_SLA_ACK    ; 0xB0  
    breq TWSI_TW_ST_ARB_LOST_SLA_ACK
    cpi tempi, TW_ST_DATA_ACK            ; 0xB8  
    breq TWSI_TW_ST_DATA_ACK
    cpi tempi, TW_ST_DATA_NACK           ; 0xC0  
    breq TWSI_TW_ST_DATA_NACK
    cpi tempi, TW_ST_LAST_DATA           ; 0xC8  
    breq TWSI_TW_ST_LAST_DATA 
    cpi tempi, TW_NO_INFO                ; 0xF8  
    breq TWSI_TW_NO_INFO
    cpi tempi, TW_BUS_ERROR              ; 0x00  
    breq TWSI_TW_BUS_ERROR 
    rjmp TWSI_TW_BUS_ERROR              ; nicht behandelte Status-Zustnde  

; SLAVE RECEIVER                
TWSI_TW_SR_SLA_ACK:                     ; x60   01100000 (SLA+W wurde empfangen-ACK wurde zurckgesendet)
    rjmp TWSI_w
TWSI_TW_SR_ARB_LOST_SLA_ACK:            ; x68   01101000 (Arbitration verloren in SLA+R/W als MASTER;  SLA+W wurde empfangen;  ACK wurde zurckgesendet
    rjmp TWSI_w
TWSI_TW_SR_GCALL_ACK:                   ; x70   01110000 (General call address wurde empfangen;  ACK wurde zurckgesendet       
    rjmp TWSI_w
TWSI_TW_SR_ARB_LOST_GCALL_ACK:          ; x78   01111000 (Arbitration verloren in SLA+R/W als MASTER;General call address wurde empfangen; ACK wurde zurckgesendet
    rjmp TWSI_w

TWSI_TW_SR_DATA_ACK:                    ; x80   10000000 (die vorher adressierten (SLA+W) Daten wurden empfangen;  ACK wurde zurckgesendet 
    lds tempi, TWDR   ; DATA
    inc WPos
    mov tempi2, WPos
    andi tempi2, RX_Buffer-1
    cp tempi2, RPos
    breq buffer_full
    mov WPos, tempi2
    clr tempi2
    ldi XL, low(RXBUF)
    ldi XH, high(RXBUF)
    add XL, WPos
    adc XH, tempi2
    st X, tempi
buffer_full:


    rjmp TWSI_w
TWSI_TW_SR_DATA_NACK:                   ; x88   10001000 (die vorher adressierten (SLA+W) Daten wurden empfangen; ACK wurde nicht zurckgesedet
    rjmp TWSI_w
TWSI_TW_SR_GCALL_DATA_ACK:              ; x90   10010000 (die vorher adressierten (General call) Daten wurden empfangen;  ACK wurde zurckgesendet  
    rjmp TWSI_w
TWSI_TW_SR_GCALL_DATA_NACK:             ; x98   10011000 (die vorher adressierten (General call) Daten wurden empfangen;  ACK wurde nicht zurckgesendet    
    rjmp TWSI_w
TWSI_TW_SR_STOP:                        ; xA0   10100000 (STOP wurde empfangen, oder wiederholter Start)
    rjmp TWSI_w
;   SLAVE TRANSMITTER       
TWSI_TW_ST_SLA_ACK:                     ; xA8   10101000 (SLA+R wurde empfangen; ACK wurde zurckgesendet)      
    sts TWDR, tempi      ; DATA
    rjmp TWSI_w
TWSI_TW_ST_ARB_LOST_SLA_ACK:            ; xB0   10110000 (Arbitration verlor SLA+R/W als MASTER, ACK wurde zurckgesendet)  
    rjmp TWSI_w
TWSI_TW_ST_DATA_ACK:                    ; xB8   10111000 (TWDR ist bertragen worden;  ACK ist empfangen worden
    sts TWDR, tempi      ; DATA
    rjmp TWSI_w
TWSI_TW_ST_DATA_NACK:                   ; xC0   11000000 (TWDR ist bertragen worden;  ACK ist NICHT empfangen worden
    sts TWDR, tempi      ; DATA
    rjmp TWSI_w
TWSI_TW_ST_LAST_DATA:                   ; xC8   11001000 (Letztes Datenbyte in TWDR ist bertragen worden (TWEA = "0");  Ack ist empfangen worden
    rjmp TWSI_w
TWSI_TW_NO_INFO:                        ; xF8   11111000 (Keine relevanten Zustandinformationen vorhanden;  TWINT = "0" keine TWDR-Ttigkeit 
    rjmp TWSI_w
TWSI_TW_BUS_ERROR:                      ; x00   00000000 (Bus-Error wegen ungltige START oder STOP Bedingung; keine TWDR-Ttigkeit 
    rcall TWI_ERROR 
TWSI_w: 
    ldi tempi, 1<<TWINT|1<<TWEA|1<<TWEN|1<<TWIE  ;das TWINT-Flag lschen ((logisch 1) 
    sts TWCR,tempi
    out sreg, regsave
    reti

TWI_ERROR:
; TWI STOP              
    ldi tempi, (1<<TWINT)|(1<<TWEN)|(1<<TWSTO)
    sts TWCR, tempi
; TWI aus               
    ldi tempi, (0<<TWEN)
    sts TWCR, tempi
; TWI INITIALISIERUNG   
    rcall TWI_INI
    ret
.endif
;------------------------------------------

;*** CG ROM Daten *** (8x10 Zeichensatz)

.org 768

.if (CSize==10)
font:
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x7F
.db 0x00,0x00,0x80,0x80,0x00,0x01,0x81,0x00,0x80,0x00,0x01,0x00,0x01,0x01,0x41,0x80,0x40,0x00,0x00,0x81,0x00,0x01,0x80,0x01,0x00,0x41,0x41,0x00,0x00,0x00,0x00,0x00 ; 0x9F
.db 0x80,0x80,0x80,0x80,0x41,0x41,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x41,0xA0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x41,0x01,0x00,0x40,0x80,0x41,0x00,0x00,0x00,0x00,0x00,0x01,0xC7 ; 0xDF
.db 0x80,0x00,0x81,0x01,0x41,0x41,0x00,0x00,0x00,0x40,0x80,0x01,0x80,0x40,0xC7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x80,0x41,0x41,0x40,0x00,0x01,0x80,0x80,0x01,0x81,0x00,0x00,0x00,0x00,0x80,0x81,0x80,0x81,0x81,0x80,0xC3,0x81,0xC3,0x81,0x81,0x00,0x00,0x00,0x00,0x00,0x81 ; 0x3F
.db 0xC3,0x80,0xC7,0xE1,0xC7,0xE3,0xE3,0xE3,0xE7,0xC1,0xC1,0x67,0x07,0x3C,0x66,0xC3,0xC3,0xC3,0xC3,0xC1,0xC7,0x63,0x66,0x66,0x66,0x6C,0xC3,0x81,0x01,0x81,0x80,0x00 ; 0x5F
.db 0x01,0x00,0x06,0x00,0xC0,0x00,0x80,0x00,0x06,0x80,0x80,0x06,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x01,0x00,0x00 ; 0x7F
.db 0xE1,0x42,0x01,0x41,0x41,0x80,0x81,0x00,0x41,0x42,0x80,0x82,0x82,0x80,0x00,0x41,0x80,0x00,0xF1,0x42,0x42,0x80,0x01,0x80,0x82,0x00,0x00,0x00,0x81,0xE3,0x00,0x40 ; 0x9F
.db 0x01,0x01,0x01,0x01,0x82,0x82,0x00,0x00,0x00,0x81,0x00,0x02,0x02,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x01,0x41,0x40,0x81,0x80,0x80,0x00,0x00,0x00,0x41,0x00 ; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x41,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x42,0x03,0xC3,0x41,0x00,0x80,0x80,0x80,0x41,0x00,0x00,0x00,0x80,0x00,0x80,0x80,0x00 ; 0xDF
.db 0x01,0x81,0x42,0x80,0x82,0x82,0x00,0x00,0x06,0x80,0x41,0x80,0x01,0x80,0x00,0x80,0x00,0x00,0x00,0x03,0xC0,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x81,0x80,0x00 ; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x80,0x41,0x41,0xC1,0x26,0x82,0x80,0x01,0x80,0x81,0x00,0x00,0x00,0x00,0x80,0x42,0x81,0x42,0x42,0x81,0x02,0x02,0x42,0x42,0x42,0x00,0x00,0x00,0x00,0x00,0x42 ; 0x3F
.db 0x24,0x80,0x22,0x22,0x22,0x21,0x21,0x24,0x42,0x80,0x80,0x42,0x02,0x66,0x43,0x24,0x21,0x24,0x21,0x42,0x45,0x22,0x24,0x24,0x42,0x44,0x42,0x01,0x01,0x80,0x41,0x00 ; 0x5F
.db 0x80,0x00,0x02,0x00,0x40,0x00,0x01,0x00,0x02,0x00,0x00,0x02,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x01,0x41,0x80 ; 0x7F
.db 0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xE3,0x00,0x92,0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0x22,0x00,0x02,0x64,0x00,0x80 ; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x66,0x80,0x81,0x80,0x42,0x00,0x22,0x22,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x42,0x80,0x80,0x00,0x00,0x00,0x41,0x00 ; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x81,0x03,0x21,0xE3,0xE3,0xE3,0x00,0xC1,0xC1,0xC1,0x00,0x00,0x80,0x00,0x80,0xC1,0x00 ; 0xDF
.db 0xC3,0x42,0xC3,0xC3,0x00,0xC3,0x00,0x06,0xC3,0x22,0x22,0x22,0x00,0x63,0x00,0x01,0x00,0x00,0x00,0x21,0xC1,0x42,0x00,0x00,0x80,0x41,0x00,0x80,0x80,0x80,0x80,0x00 ; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x80,0x00,0xE3,0x22,0x46,0x61,0x00,0x01,0x80,0x00,0x00,0x00,0x00,0x00,0x80,0x42,0x80,0x40,0x40,0x81,0x83,0x02,0x80,0x42,0x42,0x80,0x80,0x80,0x00,0x02,0x40 ; 0x3F
.db 0x99,0x41,0x22,0x02,0x22,0x01,0x01,0x04,0x42,0x80,0x80,0x82,0x02,0x66,0x43,0x24,0x21,0x24,0x21,0x02,0x01,0x22,0x42,0x24,0x81,0x82,0x80,0x01,0x01,0x80,0x00,0x00 ; 0x5F
.db 0x00,0x81,0x83,0x81,0xC1,0x81,0x01,0xC1,0x82,0x80,0x80,0x82,0x80,0x2D,0x86,0x81,0x86,0xC1,0x80,0xC0,0x81,0x42,0x42,0x22,0x42,0x42,0xC1,0x80,0x80,0x01,0x82,0x80 ; 0x7F
.db 0x02,0x42,0x81,0x81,0x81,0x81,0x81,0x81,0x81,0x81,0x81,0x01,0x01,0x80,0x80,0x80,0x21,0x63,0x82,0x81,0x81,0x81,0x42,0x42,0x42,0x22,0x22,0xE1,0x01,0xA4,0x42,0x80 ; 0x9F
.db 0x81,0x01,0x81,0x42,0x83,0x43,0x81,0x81,0x00,0xA5,0x00,0x42,0x42,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xA5,0x80,0x80,0x00,0x00,0x40,0x80,0x00 ; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x80,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x81,0x80,0x21,0x21,0x21,0x21,0x80,0x80,0x80,0x80,0x00,0x00,0x80,0x00,0x80,0x80,0x00 ; 0xDF
.db 0x24,0x42,0x24,0x24,0x81,0x24,0x00,0x83,0x22,0x22,0x22,0x22,0x42,0x41,0x00,0x00,0x00,0x80,0x00,0x43,0xC1,0x01,0x80,0x00,0x00,0x00,0x00,0x80,0x81,0x81,0x80,0x00 ; 0xFF

.db 0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x80,0x00,0x41,0x81,0x80,0xA2,0x00,0x01,0x80,0x00,0x80,0x00,0x00,0x00,0x80,0x42,0x80,0x80,0x80,0x82,0x40,0x83,0x80,0x81,0xC1,0x00,0x00,0x01,0x83,0x01,0x80 ; 0x3F
.db 0x9A,0x41,0xC3,0x02,0x22,0xC1,0xC1,0xE4,0xC3,0x80,0x80,0x03,0x02,0xA5,0xC2,0x24,0xC1,0x24,0xC1,0x81,0x01,0x22,0x42,0xA5,0x81,0x01,0x01,0x01,0x01,0x80,0x00,0x00 ; 0x5F
.db 0x00,0x40,0x42,0x42,0x42,0x42,0x81,0x42,0x43,0x80,0x80,0x03,0x80,0xD6,0x43,0x42,0x43,0x42,0x01,0x01,0x01,0x42,0x42,0xA2,0x42,0x42,0x40,0x80,0x80,0x01,0x00,0x80 ; 0x7F
.db 0x02,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x42,0x01,0x01,0x80,0x41,0x41,0x01,0x90,0xE4,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x22,0x62,0x83,0xA4,0x81,0xC1 ; 0x9F
.db 0x40,0x01,0x42,0x42,0x42,0x43,0x00,0x81,0x80,0x25,0x00,0x80,0x80,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x41,0x41,0x41,0xA5,0x80,0x80,0x80,0x80,0xC1,0xC1,0x80 ; 0xBF
.db 0x80,0x00,0x00,0x80,0x00,0x80,0x40,0x41,0x80,0x80,0x00,0x00,0x80,0x00,0x80,0x42,0x81,0xA3,0x01,0x01,0x01,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x80,0x80,0x00 ; 0xDF
.db 0x24,0xC3,0x24,0x24,0x42,0x24,0x82,0x42,0x22,0x22,0x22,0x22,0x42,0x41,0x00,0x00,0x00,0xC1,0x83,0x80,0xC0,0x82,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x80,0x00 ; 0xFF

.db 0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x80,0x00,0xE3,0x40,0x01,0x42,0x00,0x01,0x80,0x00,0xC1,0x00,0x81,0x00,0x01,0x42,0x80,0x01,0x40,0xC3,0x40,0x42,0x01,0x42,0x40,0x00,0x00,0x02,0x00,0x80,0x01 ; 0x3F
.db 0x9A,0xE3,0x22,0x02,0x22,0x01,0x01,0x24,0x42,0x80,0x80,0x82,0x02,0xA5,0xC2,0x24,0x01,0x24,0x41,0x40,0x01,0x22,0x42,0xA5,0x81,0x01,0x02,0x01,0x80,0x80,0x00,0x00 ; 0x5F
.db 0x00,0xC1,0x42,0x02,0x42,0xC3,0x01,0x42,0x42,0x80,0x80,0x03,0x80,0x94,0x42,0x42,0x42,0x42,0x01,0x80,0x01,0x42,0x42,0xA2,0x81,0x42,0x80,0x81,0x80,0x80,0x00,0x80 ; 0x7F
.db 0x02,0x42,0xC3,0xC1,0xC1,0xC1,0xC1,0x02,0xC3,0xC3,0xC3,0x01,0x01,0x80,0x41,0x41,0xC1,0xF3,0x87,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x22,0xA2,0x01,0x25,0x81,0x80 ; 0x9F
.db 0xC1,0x01,0x42,0x42,0x42,0xC2,0x81,0x00,0x80,0x42,0xC3,0x61,0x21,0x80,0x41,0x82,0x00,0x00,0x00,0x00,0x00,0x41,0x41,0x41,0x42,0x00,0x00,0xC1,0xC1,0x02,0x80,0xC1 ; 0xBF
.db 0xC1,0x81,0x81,0xC1,0x81,0xC1,0xC1,0x41,0xC1,0xC1,0x81,0x81,0x00,0x81,0xC1,0x00,0x42,0x21,0xC1,0xC1,0xC1,0x80,0x80,0x80,0x80,0xC1,0xC1,0x00,0x00,0x00,0x80,0x00 ; 0xDF
.db 0x24,0x22,0x24,0x24,0x42,0x24,0x82,0x42,0x22,0x22,0x22,0x22,0x42,0x80,0x00,0x00,0x80,0x80,0x00,0x21,0x40,0x41,0xC1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0xFF

.db 0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x00,0x00,0x41,0x22,0x62,0x42,0x00,0x01,0x80,0x00,0x80,0x00,0x00,0x00,0x01,0x42,0x80,0x42,0x42,0x80,0x42,0x42,0x01,0x42,0x40,0x00,0x00,0x01,0x83,0x01,0x00 ; 0x3F
.db 0x69,0x22,0x22,0x22,0x22,0x21,0x01,0x24,0x42,0x80,0x82,0x42,0x42,0x24,0x42,0x24,0x01,0x24,0x21,0x42,0x01,0x22,0x81,0x42,0x42,0x01,0x42,0x01,0x80,0x80,0x00,0x00 ; 0x5F
.db 0x00,0x42,0x42,0x42,0x42,0x02,0x01,0xC2,0x42,0x80,0x80,0x82,0x80,0x94,0x42,0x42,0x42,0x42,0x01,0x40,0x01,0xC2,0x81,0x41,0x42,0x42,0x01,0x80,0x80,0x01,0x00,0x80 ; 0x7F
.db 0x22,0xC2,0x02,0x42,0x42,0x42,0x42,0x42,0x02,0x02,0x02,0x01,0x01,0x80,0xC3,0xE3,0x01,0x84,0x98,0x42,0x42,0x42,0xC2,0xC2,0x42,0x22,0x22,0x23,0x02,0x26,0x42,0x80 ; 0x9F
.db 0x42,0x01,0x42,0xC2,0x42,0xC2,0x00,0x00,0x01,0x81,0x40,0x22,0x62,0x80,0x82,0x41,0x80,0x80,0x80,0x80,0x80,0xE3,0xE3,0xE3,0x81,0x80,0x80,0x80,0x80,0x02,0xC1,0x80 ; 0xBF
.db 0x80,0x00,0x00,0x80,0x00,0x80,0x42,0xE3,0x80,0x80,0x00,0x00,0x80,0x00,0x80,0x00,0x42,0x21,0x01,0x01,0x01,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x80,0x80,0x00 ; 0xDF
.db 0x24,0x22,0x24,0x24,0x42,0x24,0x82,0x42,0xC3,0x22,0x22,0x22,0x42,0x80,0x00,0x00,0x00,0x00,0x83,0x62,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00 ; 0xFF

.db 0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x80,0x00,0x41,0xC1,0x64,0xA1,0x00,0x01,0x80,0x00,0x00,0x80,0x00,0x80,0x01,0x81,0x80,0xC3,0x81,0xC1,0x81,0x81,0x01,0x81,0x81,0x80,0x80,0x80,0x00,0x02,0x01 ; 0x3F
.db 0x04,0x77,0xC7,0xC1,0xC7,0xE3,0x83,0xE3,0xE7,0xC1,0x03,0x67,0xC7,0x7E,0x47,0xC3,0x83,0xC3,0xA3,0x83,0x83,0xC1,0x81,0x42,0x66,0x83,0xC3,0x01,0x80,0x80,0x00,0x00 ; 0x5F
.db 0x00,0xC1,0x81,0x81,0xC1,0x81,0x81,0x41,0x42,0x80,0x80,0xC2,0x80,0x94,0x42,0x81,0x83,0xC1,0x01,0x81,0x80,0x41,0x81,0x41,0x42,0x81,0xC1,0x80,0x80,0x01,0x00,0x80 ; 0x7F
.db 0xC1,0x41,0x81,0xC1,0xC1,0xC1,0xC1,0x81,0x81,0x81,0x81,0x01,0x01,0x80,0x22,0x22,0x21,0x63,0xFC,0x81,0x81,0x81,0x41,0x41,0x81,0x22,0x22,0xC3,0xC3,0xC7,0x00,0x80 ; 0x9F
.db 0xC1,0x01,0x81,0x41,0x42,0x42,0x00,0x00,0x02,0x00,0x00,0x60,0x20,0x80,0x41,0x82,0x80,0x80,0x80,0x80,0x80,0x22,0x22,0x22,0x00,0x80,0x80,0x00,0x00,0xC1,0x80,0x00 ; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0x22,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x81,0xC3,0x21,0x21,0x21,0x80,0x80,0x80,0x80,0x00,0x00,0x80,0x00,0x80,0x80,0x00 ; 0xDF
.db 0x24,0xC2,0x24,0x24,0x81,0x24,0x43,0x83,0x06,0x22,0x22,0x22,0x81,0x80,0x00,0x00,0x00,0xC1,0x00,0x20,0x40,0x42,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00 ; 0xFF

.db 0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x80,0x00,0x00,0x80,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00 ; 0x3F
.db 0xC3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x80,0x00,0x00 ; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x02,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x80,0x80,0x01,0x00,0x80 ; 0x7F
.db 0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0x77,0xE3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xC1,0xC1,0x00,0x00,0x00,0x00,0x82 ; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x67,0x00,0x00,0x42,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x77,0x77,0x77,0x00,0x80,0x80,0x00,0x00,0x01,0x00,0x00 ; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0xE3,0xE3,0xE3,0x00,0xC1,0xC1,0xC1,0x00,0x00,0x80,0x00,0x80,0xC1,0x00 ; 0xDF
.db 0xC3,0x00,0xC3,0xC3,0x00,0xC3,0x02,0x02,0x00,0xC1,0xC1,0xC1,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00 ; 0xFF

.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x81,0x00,0xC7 ; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x07,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x80,0x00,0x01,0x00,0x00 ; 0x7F
.db 0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x01 ; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00 ; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xC7,0x80,0x00,0x00 ; 0xDF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x07,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00 ; 0xFF
.endif

.if (CSize==12)
font:
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00 ; 0x5F
.db 0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x7F
.db 0x00,0x00,0xC0,0x03,0x00,0x0C,0x83,0x00,0x03,0x00,0x0C,0x00,0x01,0x06,0x00,0x87,0xC0,0x00,0x00,0x03,0x00,0x0C,0x03,0x0C,0x00,0x00,0xCC,0x00,0xC3,0x00,0x00,0xE0 ; 0x9F
.db 0xC0,0xC0,0xC0,0xC0,0x00,0x67,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x55,0xD6,0x81,0x81,0xC0,0x87,0x06,0x00,0x66,0x66,0x00,0x66,0x00,0xCC,0x00 ; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x00,0x67,0x66,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0xCC,0x00,0x87,0x00,0x06,0x00,0x81,0x87,0x00,0x81,0x00,0xFF,0x00,0x00,0x06,0xFF ; 0xDF
.db 0x81,0x00,0x87,0x06,0x00,0x67,0x00,0x00,0x00,0x81,0x87,0x06,0x60,0x81,0x00,0xC0,0x00,0x00,0x00,0x0E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0xFF

.db 0x00,0xE7,0xE7,0x00,0x01,0x81,0x81,0x00,0x00,0x00,0x00,0xE3,0xC3,0x00,0xF7,0x00,0x08,0x20,0x81,0x66,0xF7,0xE7,0x00,0x81,0x81,0x81,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x03,0x66,0xC6,0x03,0x00,0x07,0x03,0xC0,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0xC7,0x01,0x87,0x87,0xC0,0xCF,0x83,0xEF,0x87,0x87,0x00,0x00,0xC0,0x00,0x06,0x87 ; 0x3F
.db 0xC7,0x03,0xCF,0xC3,0x8F,0xEF,0xEF,0xC3,0xCC,0x87,0xE1,0x6E,0x0F,0x6C,0x6C,0x83,0xCF,0x83,0xCF,0x87,0xCF,0xCC,0xCC,0x6C,0xCC,0xCC,0xEF,0xC3,0x00,0xC3,0x83,0x00 ; 0x5F
.db 0x03,0x00,0x0E,0x00,0xC1,0x00,0x83,0x00,0x0E,0x81,0xC0,0x0E,0x87,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0x81,0x0E,0x37,0x00 ; 0x7F
.db 0x87,0xCC,0x81,0x87,0xCC,0x06,0xC6,0x00,0x87,0xCC,0x06,0xC6,0x83,0x03,0xCC,0xCC,0x81,0x00,0xE3,0x87,0xCC,0x06,0x87,0x06,0x66,0xCC,0x00,0x00,0x66,0xA3,0x00,0xB1 ; 0x9F
.db 0x81,0x81,0x81,0x81,0x67,0xCD,0x87,0x87,0x03,0x83,0x00,0x26,0x36,0x03,0x00,0x00,0x29,0xAA,0xBD,0x81,0x81,0x81,0xCC,0x03,0x83,0x66,0x66,0x00,0x66,0x03,0xCC,0x00 ; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x67,0xCD,0x66,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0x03,0x8F,0xCC,0xCC,0x03,0x0F,0x03,0xCC,0xCC,0x81,0x00,0xFF,0x00,0x81,0x03,0xFF ; 0xDF
.db 0x03,0x87,0xCC,0x03,0x67,0xCD,0x00,0x00,0x0F,0x03,0xCC,0x03,0xC0,0x03,0xCF,0x81,0x00,0x00,0x00,0x33,0xF7,0xE7,0x00,0x00,0xC3,0xCC,0x00,0x03,0x87,0x87,0x00,0x00 ; 0xFF

.db 0x00,0x3C,0xFF,0x44,0x83,0xC3,0xC3,0x00,0x00,0x00,0x00,0xE0,0x66,0x00,0x36,0x81,0x0C,0x60,0xC3,0x66,0xBD,0x36,0x00,0xC3,0xC3,0x81,0x00,0x00,0x00,0x00,0x01,0xEF ; 0x1F
.db 0x00,0x87,0x66,0xC6,0xC7,0x00,0x8D,0x03,0x81,0x03,0x00,0x00,0x00,0x00,0x00,0x20,0x6C,0x03,0xCC,0xCC,0xC1,0x0C,0x06,0x6C,0xCC,0xCC,0x00,0x00,0x81,0x00,0x03,0xCC ; 0x3F
.db 0x6C,0x87,0x66,0x66,0xC6,0x26,0x66,0x66,0xCC,0x03,0xC0,0x66,0x06,0xEE,0x6C,0xC6,0x66,0xC6,0x66,0xCC,0x4B,0xCC,0xCC,0x6C,0xCC,0xCC,0xEC,0x03,0x08,0xC0,0xC6,0x00 ; 0x5F
.db 0x81,0x00,0x06,0x00,0xC0,0x00,0xC6,0x00,0x06,0x81,0xC0,0x06,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x81,0x03,0xAD,0x00 ; 0x7F
.db 0xCC,0xCC,0x03,0xCC,0xCC,0x03,0xC6,0x00,0xCC,0xCC,0x03,0xC6,0xC6,0x81,0x00,0xCC,0x00,0x00,0x87,0xCC,0xCC,0x03,0xCC,0x03,0x66,0x00,0xCC,0x00,0x06,0xC6,0x00,0x81 ; 0x9F
.db 0x03,0x03,0x03,0x03,0xCD,0x00,0xCC,0xCC,0x03,0x44,0x00,0x6E,0x6E,0x03,0x00,0x00,0x94,0x55,0x6B,0x81,0x81,0x00,0x00,0x00,0x44,0x66,0x66,0x00,0x66,0x03,0xCC,0x00 ; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0xCD,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0x8D,0xC6,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x81,0x00,0xFF,0x00,0x81,0x00,0xFF ; 0xDF
.db 0x00,0xCC,0x00,0x00,0xCD,0x00,0x00,0x0E,0x06,0x00,0x00,0x00,0x81,0x00,0x00,0x03,0x00,0x03,0x00,0x66,0xBD,0x36,0x03,0x00,0x66,0x00,0x00,0x07,0xC0,0xC0,0x00,0x00 ; 0xFF

.db 0x00,0x18,0xFF,0xEE,0xC7,0xC3,0xE7,0x00,0x00,0x00,0x00,0xA3,0x66,0x00,0xF7,0xBD,0x0E,0xE0,0xE7,0x66,0xBD,0x03,0x00,0xE7,0xE7,0x81,0x81,0x03,0x00,0x42,0x01,0xEF ; 0x1F
.db 0x00,0x87,0x66,0xEF,0x0C,0x4C,0x8D,0x03,0x03,0x81,0x66,0x81,0x00,0x00,0x00,0x60,0xEC,0x0F,0xCC,0xC0,0xC3,0x0C,0x0C,0x6C,0xCC,0xCC,0x83,0x83,0x03,0x00,0x81,0xC0 ; 0x3F
.db 0x6C,0xCC,0x66,0x6C,0x66,0x06,0x26,0x6C,0xCC,0x03,0xC0,0xC6,0x06,0xEF,0x6E,0x6C,0x66,0x6C,0x66,0xCC,0x03,0xCC,0xCC,0x6C,0xCC,0xCC,0x89,0x03,0x0C,0xC0,0x6C,0x00 ; 0x5F
.db 0x00,0x00,0x06,0x00,0xC0,0x00,0x06,0x00,0x06,0x00,0x00,0x06,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x81,0x03,0xEC,0x01 ; 0x7F
.db 0xCC,0x00,0x00,0x00,0x00,0x00,0x83,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x87,0xCF,0x00,0x8D,0x00,0x00,0x00,0x00,0x00,0x00,0x87,0xCC,0x00,0x06,0xEC,0x00,0x81 ; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x6C,0xCC,0xCC,0x00,0xAB,0x00,0xC6,0xC6,0x00,0x00,0x00,0x42,0xAA,0xD6,0x81,0x81,0x03,0x03,0x03,0xAB,0x66,0x66,0x00,0x66,0x87,0xCC,0x00 ; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x00,0x03,0x66,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0xC0,0x66,0xCF,0xCF,0xCF,0x03,0x87,0x87,0x87,0x81,0x00,0xFF,0x00,0x81,0x87,0xFF ; 0xDF
.db 0x87,0xCC,0x87,0x87,0x00,0x87,0x00,0x06,0xC7,0xCC,0xCC,0xCC,0x00,0xCC,0x00,0x00,0x00,0x03,0x00,0xC3,0xBD,0x03,0x03,0x00,0x66,0x00,0x00,0x03,0x83,0x81,0xCF,0x00 ; 0xFF

.db 0x00,0x5A,0xBD,0xEF,0xEF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x27,0x66,0x00,0x36,0xE7,0x8F,0xE3,0x81,0x66,0xBD,0xC3,0x00,0x81,0x81,0x81,0xC0,0x06,0x0C,0x66,0x83,0xC7 ; 0x1F
.db 0x00,0x87,0x42,0xC6,0x0C,0xCC,0x07,0x06,0x06,0xC0,0xC3,0x81,0x00,0x00,0x00,0xC0,0xED,0x03,0xC0,0xC0,0xC6,0x0C,0x0C,0x60,0xCC,0xCC,0x83,0x83,0x06,0xE7,0xC0,0x81 ; 0x3F
.db 0xED,0xCC,0x66,0x0C,0x66,0x46,0x46,0x0C,0xCC,0x03,0xC0,0xC6,0x06,0xEF,0x6F,0x6C,0x66,0x6C,0x66,0x0C,0x03,0xCC,0xCC,0x6C,0x87,0xCC,0x81,0x03,0x06,0xC0,0x00,0x00 ; 0x5F
.db 0x00,0x87,0xC7,0x87,0xC7,0x87,0x06,0x67,0xC6,0x87,0xC3,0x66,0x81,0xCF,0x8F,0x87,0xCD,0x67,0xCE,0x87,0xCF,0xCC,0xCC,0x6C,0x6C,0x66,0xCF,0x06,0x81,0x81,0x00,0x83 ; 0x7F
.db 0x0C,0xCC,0x87,0x87,0x87,0x87,0x8F,0x87,0x87,0x87,0x87,0x87,0x87,0x87,0x87,0x87,0x4C,0xEF,0x8D,0x87,0x87,0x87,0xCC,0xCC,0x66,0xCC,0xCC,0x87,0x06,0x6D,0x00,0xE7 ; 0x9F
.db 0x87,0x87,0x87,0xCC,0x8F,0x6E,0xE7,0x87,0x03,0xAA,0x00,0x87,0x87,0x03,0x33,0xCC,0x29,0x55,0xBD,0x81,0x81,0x87,0x87,0x87,0x2A,0x6E,0x66,0xEF,0x6E,0xCC,0x87,0x00 ; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x87,0x87,0x76,0xF7,0x7E,0xFF,0x76,0xFF,0x7E,0x00,0x60,0x66,0x4C,0x4C,0x4C,0x03,0x03,0x03,0x03,0x81,0x00,0xFF,0x00,0x81,0x03,0xFF ; 0xDF
.db 0xCC,0x8D,0xCC,0xCC,0x87,0xCC,0x66,0xC7,0x66,0xCC,0xCC,0xCC,0x66,0xCC,0x00,0x00,0x00,0xCF,0x00,0x8F,0xBD,0xC3,0x00,0x00,0x66,0x00,0x00,0x03,0xC0,0x03,0xCF,0x00 ; 0xFF

.db 0x00,0x18,0xFF,0xEF,0xEF,0x7E,0xFF,0x00,0x00,0x00,0x00,0x8F,0xC3,0x00,0x36,0x7E,0xEF,0xEF,0x81,0x66,0xB7,0x66,0x00,0x81,0x81,0x81,0xEF,0xEF,0x0C,0xFF,0x83,0xC7 ; 0x1F
.db 0x00,0x03,0x00,0xC6,0x87,0x81,0xAF,0x00,0x06,0xC0,0xFF,0xE7,0x00,0xEF,0x00,0x81,0x6D,0x03,0x81,0x83,0xCC,0x8F,0x8F,0xC0,0x87,0xC7,0x00,0x00,0x0C,0x00,0x60,0x03 ; 0x3F
.db 0xED,0xCC,0xC7,0x0C,0x66,0xC7,0xC7,0x0C,0xCF,0x03,0xC0,0x87,0x06,0x6D,0xEF,0x6C,0xC7,0x6C,0xC7,0x07,0x03,0xCC,0xCC,0x6D,0x03,0x87,0x03,0x03,0x03,0xC0,0x00,0x00 ; 0x5F
.db 0x00,0xC0,0x66,0xCC,0xCC,0xCC,0x8F,0xCC,0x67,0x81,0xC0,0xC6,0x81,0x6D,0xCC,0xCC,0x66,0xCC,0xE6,0xCC,0x06,0xCC,0xCC,0x6C,0xC6,0x66,0xC8,0x0C,0x00,0xC0,0x00,0xC6 ; 0x7F
.db 0x0C,0xCC,0xCC,0xC0,0xC0,0xC0,0xC0,0xCC,0xCC,0xCC,0xCC,0x81,0x81,0x81,0xCC,0xCC,0x0C,0xB1,0xEF,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0xCC,0xCC,0xCC,0xCF,0x6D,0x6C,0x81 ; 0x9F
.db 0xC0,0x81,0xCC,0xCC,0xCC,0x6F,0x00,0x00,0x06,0xAB,0xCF,0x03,0x73,0x03,0x66,0x66,0x94,0xAA,0x6B,0x81,0x8F,0xCC,0xCC,0xCC,0x2A,0x60,0x66,0x60,0x60,0x0C,0xCF,0x8F ; 0xBF
.db 0xF1,0xFF,0xFF,0xF1,0xFF,0xFF,0xC0,0xCC,0x06,0x06,0x00,0x00,0x06,0x00,0x00,0x6C,0xE7,0x6F,0x0C,0x0C,0x0C,0xCF,0x03,0x03,0x03,0x8F,0xF1,0xFF,0x00,0x00,0x03,0xFF ; 0xDF
.db 0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0x66,0x66,0xCC,0xCC,0xCC,0x66,0xCC,0x00,0x00,0xCF,0x03,0x8F,0x73,0xB7,0x66,0xCF,0x00,0xC3,0x00,0x81,0x87,0x87,0xC7,0xCF,0x00 ; 0xFF

.db 0x00,0xDB,0x3C,0xEF,0xC7,0x7E,0xE7,0x00,0x00,0x00,0x00,0xCC,0x81,0x00,0x36,0x7E,0x8F,0xE3,0x81,0x00,0xB1,0x66,0x00,0x81,0x81,0x81,0xC0,0x06,0x0C,0x66,0xC7,0x83 ; 0x1F
.db 0x00,0x03,0x00,0xC6,0xC0,0x03,0xED,0x00,0x06,0xC0,0xC3,0x81,0x00,0x00,0x00,0x03,0x6F,0x03,0x03,0xC0,0xEF,0xC0,0xCC,0x81,0xCC,0x81,0x00,0x00,0x06,0xE7,0xC0,0x03 ; 0x3F
.db 0xED,0xCF,0x66,0x0C,0x66,0x46,0x46,0xEC,0xCC,0x03,0xCC,0xC6,0x26,0x6C,0xED,0x6C,0x06,0xEC,0xC6,0x81,0x03,0xCC,0xCC,0x6D,0x87,0x03,0x06,0x03,0x81,0xC0,0x00,0x00 ; 0x5F
.db 0x00,0xC7,0x66,0x0C,0xCC,0xCF,0x06,0xCC,0x66,0x81,0xC0,0x87,0x81,0x6D,0xCC,0xCC,0x66,0xCC,0x67,0x06,0x06,0xCC,0xCC,0x6D,0x83,0x66,0x81,0x06,0x81,0x81,0x00,0x6C ; 0x7F
.db 0x0C,0xCC,0xCF,0xC7,0xC7,0xC7,0xC7,0x0C,0xCF,0xCF,0xCF,0x81,0x81,0x81,0xCC,0xCC,0x8F,0xF7,0x8D,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0xCC,0xCC,0xCD,0x06,0x6D,0xC6,0x81 ; 0x9F
.db 0xC7,0x81,0xCC,0xCC,0xCC,0xED,0xEF,0xEF,0x0C,0x2B,0xC0,0xE6,0xF6,0x87,0xCC,0x33,0x42,0x55,0xD6,0x81,0x81,0xCC,0xCC,0xCC,0x2A,0x60,0x66,0x60,0x60,0x0C,0x03,0x81 ; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0xC7,0xCC,0x06,0x06,0x00,0x00,0x06,0x00,0x00,0xC7,0x6C,0x66,0x8F,0x8F,0x8F,0x00,0x03,0x03,0x03,0x00,0x81,0xFF,0xFF,0x81,0x03,0x00 ; 0xDF
.db 0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0x66,0x66,0xCC,0xCC,0xCC,0x66,0x87,0x00,0x00,0x00,0x03,0x00,0xF6,0xB1,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCF,0x00 ; 0xFF

.db 0x00,0x99,0x7E,0xC7,0x83,0x81,0x81,0x00,0x00,0x00,0x00,0xCC,0xE7,0x00,0x76,0xE7,0x0E,0xE0,0xE7,0x00,0xB1,0xC3,0xEF,0xE7,0x81,0xE7,0x81,0x03,0xEF,0x42,0xC7,0x83 ; 0x1F
.db 0x00,0x00,0x00,0xEF,0xC0,0x06,0xCC,0x00,0x03,0x81,0x66,0x81,0x00,0x00,0x00,0x06,0x6E,0x03,0x06,0xC0,0xC0,0xC0,0xCC,0x03,0xCC,0x81,0x83,0x83,0x03,0x00,0x81,0x00 ; 0x3F
.db 0x0C,0xCC,0x66,0x6C,0x66,0x06,0x06,0x6C,0xCC,0x03,0xCC,0xC6,0x66,0x6C,0xEC,0x6C,0x06,0xED,0x66,0xCC,0x03,0xCC,0xCC,0xC6,0xCC,0x03,0x26,0x03,0xC0,0xC0,0x00,0x00 ; 0x5F
.db 0x00,0xCC,0x66,0x0C,0xCC,0x0C,0x06,0xCC,0x66,0x81,0xC0,0xC6,0x81,0x6D,0xCC,0xCC,0x66,0xCC,0x06,0x81,0x06,0xCC,0xCC,0x6D,0x83,0x66,0x06,0x03,0x81,0x03,0x00,0x6C ; 0x7F
.db 0xCC,0xCC,0x0C,0xCC,0xCC,0xCC,0xCC,0x0C,0x0C,0x0C,0x0C,0x81,0x81,0x81,0xCF,0xCF,0x0C,0x8D,0x8D,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0xCC,0xCC,0xCE,0x06,0x6E,0x83,0x81 ; 0x9F
.db 0xCC,0x81,0xCC,0xCC,0xCC,0xEC,0x00,0x00,0x0C,0xAA,0xC0,0x3C,0xBD,0x87,0xCC,0x33,0x29,0xAA,0xBD,0x81,0x81,0xCF,0xCF,0xCF,0xAB,0x6E,0x66,0x6E,0xEF,0xCC,0xCF,0x81 ; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0xCC,0xCF,0xF7,0x76,0xFF,0x7E,0x76,0xFF,0x7E,0xC6,0x6C,0x66,0x0C,0x0C,0x0C,0x00,0x03,0x03,0x03,0x00,0x81,0xFF,0xFF,0x81,0x03,0x00 ; 0xDF
.db 0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0xC7,0xC7,0xCC,0xCC,0xCC,0x66,0x03,0x00,0x00,0x00,0x00,0x00,0xBD,0xB1,0xC3,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCF,0x00 ; 0xFF

.db 0x00,0x3C,0xFF,0x83,0x01,0x81,0x81,0x00,0x00,0x00,0x00,0xCC,0x81,0x00,0x7E,0xBD,0x0C,0x60,0xC3,0x66,0xB1,0xC0,0xEF,0xC3,0x81,0xC3,0x00,0x00,0x00,0x00,0xEF,0x01 ; 0x1F
.db 0x00,0x03,0x00,0xC6,0x8F,0xCC,0xCD,0x00,0x81,0x03,0x00,0x00,0x83,0x00,0x83,0x0C,0x6C,0x03,0xCC,0xCC,0xC0,0xCC,0xCC,0x03,0xCC,0x03,0x83,0x83,0x81,0x00,0x03,0x03 ; 0x3F
.db 0x0C,0xCC,0x66,0x66,0xC6,0x26,0x06,0x66,0xCC,0x03,0xCC,0x66,0x66,0x6C,0x6C,0xC6,0x06,0xC7,0x66,0xCC,0x03,0xCC,0x87,0xC6,0xCC,0x03,0x6C,0x03,0x60,0xC0,0x00,0x00 ; 0x5F
.db 0x00,0xCC,0x66,0xCC,0xCC,0xCC,0x06,0xC7,0x66,0x81,0xC0,0x66,0x81,0x6D,0xCC,0xCC,0x66,0xCC,0x06,0xCC,0xC6,0xCC,0x87,0xC6,0xC6,0xC3,0x4C,0x03,0x81,0x03,0x00,0xEF ; 0x7F
.db 0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0x0C,0x0C,0x0C,0x81,0x81,0x81,0xCC,0xCC,0x4C,0x8D,0x8D,0xCC,0xCC,0xCC,0xCC,0xCC,0xC3,0xCC,0xCC,0xCC,0x0C,0xC6,0xC6,0x8D ; 0x9F
.db 0xCC,0x81,0xCC,0xCC,0xCC,0x6C,0x00,0x00,0xCC,0x44,0xC0,0x68,0x3B,0x87,0x66,0x66,0x94,0x55,0x6B,0x81,0x81,0xCC,0xCC,0xCC,0x44,0x66,0x66,0x66,0x00,0x87,0x03,0x81 ; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0xCC,0xCC,0x00,0x66,0x00,0x66,0x66,0x00,0x66,0xC7,0x6C,0xC6,0x4C,0x4C,0x4C,0x00,0x03,0x03,0x03,0x00,0x81,0xFF,0xFF,0x81,0x03,0x00 ; 0xDF
.db 0xCC,0x8F,0xCC,0xCC,0xCC,0xCC,0x66,0x06,0x06,0xCC,0xCC,0xCC,0xC3,0x03,0x00,0x00,0x00,0xCF,0x8F,0x3B,0xB1,0xC0,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCF,0x00 ; 0xFF

.db 0x00,0xE7,0xE7,0x01,0x00,0xE7,0xE7,0x00,0x00,0x00,0x00,0x87,0x81,0x00,0x6E,0x81,0x08,0x20,0x81,0x66,0xB1,0x6C,0xEF,0x81,0x81,0x81,0x00,0x00,0x00,0x00,0xEF,0x01 ; 0x1F
.db 0x00,0x03,0x00,0xC6,0x03,0xC8,0x67,0x00,0xC0,0x06,0x00,0x00,0x83,0x00,0x83,0x08,0xC7,0xCF,0xCF,0x87,0xE1,0x87,0x87,0x03,0x87,0x07,0x00,0x81,0xC0,0x00,0x06,0x03 ; 0x3F
.db 0xC7,0xCC,0xCF,0xC3,0x8F,0xEF,0x0F,0xE3,0xCC,0x87,0x87,0x6E,0xEF,0x6C,0x6C,0x83,0x0F,0xC0,0x6E,0x87,0x87,0x87,0x03,0xC6,0xCC,0x87,0xEF,0xC3,0x20,0xC3,0x00,0x00 ; 0x5F
.db 0x00,0x67,0xCD,0x87,0x67,0x87,0x0F,0xC0,0x6E,0xE7,0xCC,0x6E,0xE7,0x6C,0xCC,0x87,0xC7,0xC7,0x0F,0x87,0x83,0x67,0x03,0xC6,0x6C,0xC0,0xCF,0xC1,0x81,0x0E,0x00,0x00 ; 0x7F
.db 0x87,0x67,0x87,0x67,0x67,0x67,0x67,0x87,0xC7,0xC7,0xC7,0xE7,0xE7,0xE7,0xCC,0xCC,0xCF,0xFE,0xED,0x87,0x87,0x87,0x67,0x67,0xC0,0x87,0x87,0x87,0xEF,0x8B,0x6C,0x07 ; 0x9F
.db 0x67,0xE7,0x87,0x67,0xCC,0x6C,0x00,0x00,0x87,0x83,0x00,0xC0,0xF3,0x03,0x33,0xCC,0x42,0xAA,0xD6,0x81,0x81,0xCC,0xCC,0xCC,0x83,0x66,0x66,0x66,0x00,0x03,0x03,0x81 ; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0x67,0xCC,0x00,0x66,0x00,0x66,0x66,0x00,0x66,0x6C,0xC7,0x8F,0xCF,0xCF,0xCF,0x00,0x87,0x87,0x87,0x00,0x81,0xFF,0xFF,0x81,0x87,0x00 ; 0xDF
.db 0x87,0x0C,0x87,0x87,0x87,0x87,0xB7,0x0F,0x0F,0x87,0x87,0x87,0xC0,0x87,0x00,0x00,0x00,0x00,0x00,0xF3,0xB1,0x6C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x00,0xE7,0x00,0xE7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00 ; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF ; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCC,0x00,0x00,0xCC,0x00,0x00,0x00,0x00,0x00,0x06,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x7F
.db 0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF1,0x30,0x00,0x00,0x00,0x29,0x55,0xBD,0x81,0x81,0x00,0x00,0x00,0x00,0x66,0x66,0x66,0x00,0x03,0x00,0x81 ; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0x00,0x00,0x00,0x66,0x00,0x66,0x66,0x00,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0xFF,0xFF,0x00,0x00,0x00 ; 0xDF
.db 0x00,0x06,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x00,0xE7,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x1F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x87,0x00,0x00,0x87,0x00,0x00,0x00,0x00,0x00,0x0F,0xE1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x7F
.db 0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x94,0xAA,0x6B,0x81,0x81,0x00,0x00,0x00,0x00,0x66,0x66,0x66,0x00,0x00,0x00,0x81 ; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0x00,0x00,0x00,0x66,0x00,0x66,0x66,0x00,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0xFF,0xFF,0x00,0x00,0x00 ; 0xDF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ; 0xFF
.endif

.if (CSize==24)
font:
.db 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0xC0, 0x03, 0xC0, 0x03, 0x60, 0x81, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0xF0, 0x0C, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x10, 0x08, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0xC1, 0x07, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x30, 0x08
.db 0x00, 0x81, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0xCF, 0x06, 0x00, 0xF3, 0x0C, 0x00, 0x00, 0x00, 0x00
.db 0x10, 0x0C, 0x00, 0x00, 0x83, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00
.db 0x83, 0x00, 0x10, 0x0C, 0x00, 0x07, 0xC1, 0x00, 0xF1, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x8F, 0x10, 0x08, 0xE3, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0xF1, 0x0E, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x10, 0x08, 0x00, 0x00
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x70, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x10, 0x0C, 0xC1, 0x07, 0x10, 0xC8, 0x30, 0x8F, 0xC3, 0x30, 0x70, 0x0C, 0x30, 0x08
.db 0x00, 0x87, 0xC3, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC0
.db 0x70, 0x0C, 0x00, 0x0C, 0xF0, 0x0C, 0xF0, 0x0C, 0x00, 0x07, 0xF0, 0xCF, 0x10, 0x8F, 0xF1, 0xCF
.db 0x30, 0x0E, 0x30, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF1, 0x0E
.db 0x30, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0xCF, 0x03, 0x00, 0xF3, 0x0C, 0x00, 0x08, 0x00, 0x00
.db 0x00, 0x0E, 0x00, 0x00, 0x83, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x00, 0x00, 0x10, 0xFF, 0x00, 0x00
.db 0x83, 0x00, 0x10, 0x0C, 0x00, 0x07, 0xC1, 0x00, 0xF1, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x8F, 0x10, 0x08, 0xF3, 0x00, 0x00, 0x00, 0x70, 0x0F
.db 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x03, 0xC0, 0x06
.db 0xC0, 0x06, 0xC3, 0x07, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x10, 0x08, 0x00, 0x00
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0xF0, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x10, 0x0C, 0xC1, 0x07, 0x10, 0xC8, 0xF0, 0xCF, 0x66, 0x60, 0xF0, 0x0E, 0x30, 0x08
.db 0x00, 0x0F, 0xE1, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC0
.db 0xF0, 0x0E, 0x70, 0x0C, 0xF3, 0x0E, 0xF1, 0x0F, 0x00, 0x0F, 0xF0, 0xCF, 0x70, 0xCF, 0xF1, 0xCF
.db 0xF0, 0x0F, 0xF0, 0x8F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF3, 0x8F
.db 0x70, 0x8F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x08, 0x03, 0x00, 0x10, 0x0C, 0x00, 0x08, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x83, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x00, 0x00, 0x30, 0x0C, 0x00, 0x00
.db 0x83, 0x00, 0x10, 0x0C, 0x00, 0x07, 0xC1, 0x00, 0x00, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x0C, 0x10, 0x08, 0x70, 0x08, 0x00, 0x00, 0xF0, 0x8F
.db 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x03, 0xC0, 0x06
.db 0xC0, 0x06, 0x83, 0x07, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x10, 0x08, 0x00, 0x00
.db 0x30, 0x0C, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0xC1, 0x83, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x10, 0x0C, 0xC1, 0x07, 0x30, 0x81, 0xE0, 0x4C, 0x3C, 0xC0, 0xC1, 0x07, 0x30, 0x08
.db 0x10, 0x0C, 0x70, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x81
.db 0xC1, 0x07, 0xF3, 0x0C, 0x03, 0x07, 0x01, 0x87, 0x10, 0x0F, 0xF0, 0xCF, 0xF0, 0x40, 0xF1, 0xCF
.db 0xE1, 0x87, 0xC1, 0x83, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0xC3
.db 0xE0, 0xC1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x08, 0x81, 0x00, 0x10, 0x0C, 0x10, 0x0C, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x83, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x00, 0x00, 0x30, 0x08, 0x00, 0x00
.db 0x83, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC1, 0x00, 0x00, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x08, 0x10, 0x08, 0x30, 0x08, 0x00, 0x00, 0xC1, 0xC1
.db 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x30, 0x08, 0x70, 0x0E, 0x83, 0xE0, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x83, 0x07, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x10, 0x08, 0x00, 0x00
.db 0x70, 0x0E, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x81, 0x81, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x10, 0x0C, 0xC1, 0x07, 0x30, 0x81, 0xC1, 0x0C, 0x3C, 0x81, 0xC1, 0x07, 0x30, 0x08
.db 0x30, 0x08, 0x30, 0x08, 0x91, 0x8D, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x81
.db 0x83, 0x83, 0x13, 0x0C, 0x00, 0x83, 0x00, 0x83, 0x10, 0x0F, 0xC0, 0x00, 0xE0, 0x00, 0x00, 0x81
.db 0xC1, 0x83, 0xC1, 0xC1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0xC1
.db 0x81, 0xC0, 0x30, 0x08, 0xF3, 0x0E, 0x30, 0x8F, 0xF3, 0x0E, 0xF1, 0xCF, 0xF1, 0xEF, 0x30, 0x8F
.db 0x83, 0xC1, 0xF3, 0x8F, 0xF1, 0x0F, 0x83, 0xE1, 0xC1, 0x00, 0x07, 0xC1, 0x83, 0xC0, 0x70, 0x0E
.db 0xF1, 0x8F, 0x70, 0x0E, 0xF3, 0x0E, 0x70, 0x0F, 0xFF, 0xEF, 0x83, 0xE0, 0x0E, 0x70, 0x0C, 0x30
.db 0x87, 0x70, 0x0E, 0x70, 0xF3, 0xCF, 0x30, 0x08, 0x81, 0x00, 0x10, 0x0C, 0x10, 0x0C, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x83, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x00, 0x00, 0x30, 0x08, 0x00, 0x00
.db 0x83, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC1, 0x00, 0x00, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x08, 0x10, 0x08, 0x30, 0x08, 0x00, 0x00, 0x83, 0xE0
.db 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x30, 0x0C, 0xF0, 0x0F, 0x83, 0xE0, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x83, 0x06, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00
.db 0x04, 0x00, 0x00, 0x20, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x10, 0x08, 0x00, 0x00
.db 0xD0, 0x0B, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x81, 0x81, 0x00, 0x00, 0x00, 0x08, 0xF7, 0xEF
.db 0x00, 0x00, 0x10, 0x0C, 0x80, 0x02, 0x30, 0x81, 0xC1, 0x0C, 0x3C, 0x81, 0xC1, 0x07, 0x10, 0x00
.db 0x70, 0x00, 0x10, 0x0C, 0xE3, 0xC7, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03
.db 0x83, 0x83, 0x10, 0x0C, 0x00, 0x83, 0x00, 0x83, 0x30, 0x07, 0xC0, 0x00, 0xC1, 0x00, 0x00, 0x81
.db 0xC1, 0x83, 0x83, 0xC1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC1
.db 0x83, 0xC7, 0x30, 0x0C, 0xF3, 0x0F, 0xF0, 0xCF, 0xF3, 0x0F, 0xF1, 0xCF, 0xF1, 0xEF, 0xF0, 0xCF
.db 0x83, 0xC1, 0xF3, 0x8F, 0xF1, 0x0F, 0x83, 0xC3, 0xC1, 0x00, 0x87, 0xC3, 0x83, 0xC0, 0xF0, 0x0F
.db 0xF1, 0xCF, 0xF0, 0x0F, 0xF3, 0x0F, 0xF1, 0x8F, 0xFF, 0xEF, 0x83, 0xE0, 0x07, 0xE0, 0x0C, 0x30
.db 0xC3, 0xE0, 0x07, 0xE0, 0xF3, 0xCF, 0x30, 0x08, 0xC0, 0x00, 0x10, 0x0C, 0x30, 0x0C, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x83, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x00, 0x00, 0x30, 0x08, 0x00, 0x00
.db 0x83, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC1, 0x00, 0x00, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x08, 0x10, 0x08, 0x30, 0x08, 0x00, 0x00, 0x13, 0x6F
.db 0xFF, 0xFF, 0x70, 0x0E, 0x00, 0x00, 0x70, 0x0C, 0xC1, 0x83, 0x83, 0xE0, 0x70, 0x0E, 0x70, 0x0C
.db 0x83, 0xC1, 0x83, 0x0E, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00
.db 0x07, 0x00, 0x00, 0xE0, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x10, 0x08, 0x10, 0x08
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x81, 0x81, 0x00, 0x00, 0x00, 0x08, 0xF3, 0xCF
.db 0x00, 0x00, 0x10, 0x0C, 0x80, 0x02, 0x30, 0x81, 0xC1, 0x0C, 0x3C, 0x03, 0xC1, 0x06, 0x10, 0x00
.db 0x70, 0x00, 0x10, 0x0C, 0xC0, 0x03, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03
.db 0x07, 0xC1, 0x10, 0x0C, 0x00, 0x83, 0x00, 0x83, 0x70, 0x07, 0xC0, 0x00, 0xC1, 0x00, 0x00, 0x03
.db 0xC1, 0x83, 0x83, 0xE0, 0x30, 0x0C, 0x30, 0x0C, 0x00, 0x20, 0x00, 0x00, 0x04, 0x00, 0x00, 0xC1
.db 0x03, 0xC8, 0x70, 0x0C, 0x83, 0x87, 0xE1, 0xC0, 0x83, 0xC3, 0xC1, 0x00, 0xC1, 0x00, 0xE1, 0xC0
.db 0x83, 0xC1, 0x30, 0x08, 0x00, 0x07, 0x83, 0x87, 0xC1, 0x00, 0x87, 0xC3, 0xC3, 0xC0, 0xC1, 0x83
.db 0xC1, 0xE1, 0xC1, 0x83, 0x83, 0x87, 0xC3, 0x81, 0x30, 0x08, 0x83, 0xE0, 0x07, 0xE0, 0x0E, 0x30
.db 0xE1, 0xC1, 0x83, 0xC0, 0x00, 0xC1, 0x30, 0x08, 0xC0, 0x00, 0x10, 0x0C, 0x30, 0x06, 0x00, 0x00
.db 0x00, 0x00, 0x70, 0x0E, 0x93, 0x0E, 0x30, 0x8F, 0x30, 0xEC, 0x30, 0x0E, 0xF3, 0xEF, 0x30, 0xEC
.db 0x83, 0x0F, 0xF3, 0x0C, 0xF1, 0x0F, 0xC1, 0xC3, 0x00, 0x0E, 0x37, 0xC8, 0x83, 0x0F, 0x70, 0x0C
.db 0x93, 0x0E, 0x70, 0xC9, 0xE0, 0xC7, 0x70, 0x0F, 0xF3, 0xCF, 0x83, 0xC1, 0x87, 0xE0, 0x0C, 0x30
.db 0x87, 0xC0, 0x87, 0xE0, 0xF3, 0xCF, 0x10, 0x0C, 0x10, 0x08, 0x70, 0x00, 0x00, 0x00, 0x77, 0x7F
.db 0xFF, 0xFF, 0xC0, 0x03, 0x00, 0x00, 0x60, 0x0E, 0x83, 0xC1, 0x83, 0xE0, 0xF1, 0x0F, 0xF1, 0x0F
.db 0x83, 0xC1, 0x93, 0x0C, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00
.db 0xC7, 0x00, 0x00, 0xE3, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x10, 0x08, 0x10, 0x08
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x81, 0x81, 0x00, 0x00, 0x10, 0x0C, 0xF3, 0xCF
.db 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0xF3, 0xEF, 0xE1, 0x0C, 0x3C, 0x06, 0xE0, 0x0E, 0x00, 0x00
.db 0x70, 0x00, 0x10, 0x0C, 0x20, 0x04, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06
.db 0x07, 0xC1, 0x10, 0x0C, 0x00, 0x83, 0x00, 0x03, 0x60, 0x07, 0xC0, 0x00, 0x83, 0x00, 0x00, 0x03
.db 0xE1, 0x03, 0x83, 0xE0, 0x30, 0x0C, 0x30, 0x0C, 0x00, 0xE0, 0x00, 0x00, 0x07, 0x00, 0x00, 0x83
.db 0x17, 0xC8, 0x60, 0x0E, 0x83, 0x83, 0xC3, 0x00, 0x83, 0xC1, 0xC1, 0x00, 0xC1, 0x00, 0xC3, 0x00
.db 0x83, 0xC1, 0x30, 0x08, 0x00, 0x07, 0x83, 0x0F, 0xC1, 0x00, 0x87, 0xC3, 0xE3, 0xC0, 0x83, 0xC1
.db 0xC1, 0xE0, 0x83, 0xC1, 0x83, 0x83, 0x83, 0x00, 0x30, 0x08, 0x83, 0xE0, 0x83, 0xE0, 0x16, 0x68
.db 0xE1, 0x83, 0x83, 0x81, 0x00, 0x83, 0x30, 0x08, 0x60, 0x00, 0x10, 0x0C, 0x70, 0x06, 0x00, 0x00
.db 0x00, 0x00, 0xF1, 0x0F, 0xB3, 0x8F, 0xF0, 0xCF, 0xF0, 0xEF, 0xF0, 0x0F, 0xF3, 0xEF, 0xF0, 0xEF
.db 0xB3, 0x8F, 0xF3, 0x0C, 0xF1, 0x0F, 0xC1, 0x87, 0x00, 0x0E, 0x77, 0xE9, 0xB3, 0x8F, 0xF1, 0x0F
.db 0xB3, 0x8F, 0xF1, 0xCF, 0xE0, 0xCF, 0xF0, 0x8F, 0xF3, 0xCF, 0x83, 0xC1, 0x83, 0xC1, 0x1E, 0x3C
.db 0xC3, 0x81, 0x83, 0xC0, 0xF3, 0xCF, 0x10, 0x0C, 0x10, 0x08, 0x70, 0x00, 0x00, 0x00, 0x66, 0x31
.db 0xFF, 0xFF, 0x01, 0x80, 0x00, 0x00, 0x60, 0x0E, 0x83, 0xC1, 0x83, 0xE0, 0x81, 0x87, 0xC3, 0x87
.db 0x83, 0xC1, 0x93, 0x0C, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00
.db 0xF7, 0x00, 0x00, 0xEF, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x10, 0x08, 0x10, 0x08
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x02, 0x40, 0x00, 0xC1, 0x83, 0x40, 0x02, 0x10, 0x0C, 0xF1, 0x8F
.db 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0xF3, 0xEF, 0xF0, 0x0C, 0x66, 0x0C, 0xF0, 0x08, 0x00, 0x00
.db 0xE0, 0x00, 0x00, 0x0E, 0x70, 0x0E, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06
.db 0x07, 0xC1, 0x10, 0x0C, 0x00, 0x07, 0x00, 0x06, 0xC0, 0x07, 0xC0, 0x00, 0x93, 0x0F, 0x00, 0x06
.db 0xF0, 0x0F, 0x83, 0xE0, 0x30, 0x0C, 0x30, 0x0C, 0x00, 0xC3, 0x00, 0x00, 0xC3, 0x00, 0x00, 0x87
.db 0x36, 0xC0, 0x60, 0x0E, 0x83, 0x83, 0x83, 0x00, 0x83, 0xE1, 0xC1, 0x00, 0xC1, 0x00, 0x83, 0x00
.db 0x83, 0xC1, 0x30, 0x08, 0x00, 0x07, 0x83, 0x0E, 0xC1, 0x00, 0xC6, 0xC6, 0xE3, 0xC0, 0x83, 0xC1
.db 0xC1, 0xE0, 0x83, 0xC1, 0x83, 0x83, 0x83, 0x00, 0x30, 0x08, 0x83, 0xE0, 0x83, 0xC1, 0x36, 0x6C
.db 0xF0, 0x07, 0xC1, 0x83, 0x00, 0x07, 0x30, 0x08, 0x60, 0x00, 0x10, 0x0C, 0x60, 0x03, 0x00, 0x00
.db 0x00, 0x00, 0x81, 0x87, 0xE3, 0x83, 0xE1, 0x40, 0xE1, 0xE3, 0xE1, 0x83, 0x30, 0x08, 0xE1, 0xE3
.db 0xE3, 0xC3, 0x10, 0x0C, 0x00, 0x07, 0xC1, 0x07, 0x00, 0x0E, 0xF7, 0xEF, 0xE3, 0xC3, 0xC3, 0x87
.db 0xE3, 0x83, 0xC3, 0xC7, 0xF0, 0xC8, 0xE1, 0x80, 0x70, 0x00, 0x83, 0xC1, 0x83, 0xC1, 0x1E, 0x2C
.db 0xE1, 0x03, 0x83, 0xC1, 0x00, 0xC1, 0x10, 0x0C, 0x10, 0x08, 0x70, 0x00, 0x00, 0x00, 0xC6, 0x30
.db 0xFF, 0xFF, 0x62, 0x46, 0x00, 0x00, 0xE0, 0x06, 0x07, 0xE0, 0x83, 0xE0, 0x00, 0x83, 0x83, 0x83
.db 0x83, 0xC1, 0x93, 0x0C, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00
.db 0xF7, 0x08, 0x10, 0xEF, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x10, 0x08, 0x10, 0x08
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x03, 0xC0, 0x00, 0xF0, 0x0F, 0xC0, 0x03, 0x30, 0x0C, 0xF1, 0x8F
.db 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x60, 0x03, 0x70, 0x0C, 0xC3, 0x0C, 0xF1, 0x00, 0x00, 0x00
.db 0xE0, 0x00, 0x00, 0x0E, 0xE0, 0x07, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C
.db 0x07, 0xC1, 0x10, 0x0C, 0x00, 0x07, 0x70, 0x0C, 0x81, 0x07, 0xF0, 0x0C, 0xB3, 0x8F, 0x00, 0x04
.db 0x70, 0x0C, 0xC3, 0xE1, 0x30, 0x0C, 0x30, 0x0C, 0x00, 0x0F, 0xF7, 0xEF, 0xF0, 0x00, 0x00, 0x0F
.db 0x36, 0xC0, 0xE0, 0x06, 0x83, 0x07, 0x07, 0x00, 0x83, 0xE0, 0xC1, 0x00, 0xC1, 0x00, 0x07, 0x00
.db 0x83, 0xC1, 0x30, 0x08, 0x00, 0x07, 0x93, 0x0C, 0xC1, 0x00, 0xC6, 0xC6, 0xF3, 0xC0, 0x07, 0xE0
.db 0xC1, 0xE0, 0x07, 0xE0, 0x83, 0x83, 0xC3, 0x00, 0x30, 0x08, 0x83, 0xE0, 0xC3, 0xC1, 0x36, 0x6C
.db 0x70, 0x0E, 0xE1, 0x07, 0x00, 0x0E, 0x30, 0x08, 0x30, 0x00, 0x10, 0x0C, 0xC0, 0x03, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x83, 0xC3, 0xC1, 0xC1, 0x00, 0xC1, 0xE0, 0xC1, 0xC1, 0x30, 0x08, 0xC1, 0xE0
.db 0xC3, 0xC1, 0x10, 0x0C, 0x00, 0x07, 0xC1, 0x0F, 0x00, 0x0E, 0x97, 0xEE, 0xC3, 0xC1, 0x83, 0x83
.db 0xC3, 0xC1, 0x83, 0xC1, 0xF0, 0xC0, 0xC1, 0x00, 0x70, 0x00, 0x83, 0xC1, 0xC3, 0xC1, 0x36, 0x6C
.db 0xE0, 0x07, 0xC1, 0x81, 0x00, 0x83, 0x10, 0x0C, 0x10, 0x08, 0x70, 0x00, 0x00, 0x00, 0xC6, 0x30
.db 0xFF, 0xFF, 0x66, 0x66, 0x00, 0x00, 0xC0, 0x07, 0x07, 0xE0, 0x83, 0xE0, 0x00, 0x83, 0x07, 0xC1
.db 0x83, 0xC1, 0x93, 0x0E, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00
.db 0xF7, 0x0E, 0x70, 0xEF, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x10, 0x08, 0xF7, 0xEF
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x81, 0x81, 0x00, 0x70, 0x0E, 0x81, 0x81, 0x30, 0x0E, 0xF0, 0x8F
.db 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x60, 0x06, 0x10, 0x0E, 0x10, 0x08, 0xF3, 0x70, 0x00, 0x00
.db 0xE0, 0x00, 0x00, 0x0E, 0xC1, 0x83, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C
.db 0x07, 0xC1, 0x10, 0x0C, 0x00, 0x0E, 0x70, 0x0E, 0x81, 0x07, 0xF0, 0x0F, 0xE3, 0xC3, 0x00, 0x0C
.db 0xF0, 0x0F, 0xE1, 0xE3, 0x00, 0x00, 0x00, 0x00, 0x30, 0x0C, 0xF7, 0xEF, 0x30, 0x0C, 0x10, 0x0E
.db 0x36, 0xC1, 0xC0, 0x07, 0xF3, 0x0E, 0x07, 0x00, 0x83, 0xE0, 0xC1, 0x00, 0xC1, 0x00, 0x07, 0x00
.db 0x83, 0xC1, 0x30, 0x08, 0x00, 0x07, 0xB3, 0x08, 0xC1, 0x00, 0xC6, 0xC6, 0x73, 0xC8, 0x07, 0xE0
.db 0xC1, 0xE1, 0x07, 0xE0, 0x83, 0x07, 0xF1, 0x00, 0x30, 0x08, 0x83, 0xE0, 0xC1, 0xC1, 0x36, 0x6C
.db 0x30, 0x0C, 0xE0, 0x0E, 0x10, 0x0C, 0x30, 0x08, 0x30, 0x00, 0x10, 0x0C, 0xC0, 0x81, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x83, 0x83, 0xC1, 0x83, 0x00, 0x83, 0xE0, 0x83, 0xC1, 0x30, 0x08, 0x83, 0xE0
.db 0x83, 0xC1, 0x10, 0x0C, 0x00, 0x07, 0xD1, 0x0E, 0x00, 0x0E, 0x97, 0xEC, 0x83, 0xC1, 0x07, 0xC1
.db 0x83, 0xC1, 0x07, 0xC1, 0xE0, 0x00, 0xC1, 0x00, 0x70, 0x00, 0x83, 0xC1, 0xC1, 0x81, 0x36, 0x6C
.db 0xF0, 0x06, 0xC1, 0x83, 0x00, 0x07, 0x30, 0x08, 0x10, 0x08, 0x30, 0x08, 0x00, 0x00, 0xC6, 0x30
.db 0xFF, 0xFF, 0x04, 0x20, 0x00, 0x00, 0xC1, 0x07, 0x07, 0xE0, 0x83, 0xE0, 0x70, 0x8F, 0x07, 0xC1
.db 0x83, 0xC1, 0x83, 0x0F, 0x10, 0xFF, 0x10, 0x08, 0xFF, 0x08, 0x10, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF
.db 0xF7, 0x8F, 0xF1, 0xEF, 0x10, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0xFF, 0x08, 0xF7, 0xEF
.db 0x10, 0x08, 0x10, 0x08, 0xF7, 0xEF, 0xF7, 0xEF, 0x00, 0x00, 0xF7, 0xEF, 0x70, 0x0E, 0xF0, 0x0F
.db 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0xC0, 0x06, 0x00, 0x8F, 0x30, 0xC3, 0x37, 0x78, 0x00, 0x00
.db 0xE0, 0x00, 0x00, 0x0E, 0x40, 0x02, 0x10, 0x08, 0x00, 0x00, 0xF1, 0x8F, 0x00, 0x00, 0x10, 0x08
.db 0x07, 0xC1, 0x10, 0x0C, 0x10, 0x0C, 0x00, 0x0F, 0x03, 0x07, 0x00, 0x87, 0xC3, 0xE1, 0x10, 0x08
.db 0xC1, 0x8F, 0xF0, 0xEE, 0x00, 0x00, 0x00, 0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x0F, 0x10, 0x0C
.db 0x36, 0xC1, 0xC1, 0x07, 0xF3, 0x0E, 0x07, 0x00, 0x83, 0xE0, 0xF1, 0x8F, 0xF1, 0xCF, 0x07, 0x00
.db 0xF3, 0xCF, 0x30, 0x08, 0x00, 0x07, 0xF3, 0x00, 0xC1, 0x00, 0x66, 0xC4, 0x33, 0xC8, 0x07, 0xE0
.db 0xC1, 0xC3, 0x07, 0xE0, 0xF3, 0x0E, 0xF0, 0x0E, 0x30, 0x08, 0x83, 0xE0, 0xC1, 0x83, 0x36, 0x6C
.db 0x30, 0x0C, 0x70, 0x0C, 0x10, 0x08, 0x30, 0x08, 0x10, 0x08, 0x10, 0x0C, 0x81, 0x81, 0x00, 0x00
.db 0x00, 0x00, 0x70, 0x8F, 0x83, 0xC1, 0x83, 0x00, 0x83, 0xE0, 0x83, 0xC1, 0x30, 0x08, 0x83, 0xE0
.db 0x83, 0xC1, 0x10, 0x0C, 0x00, 0x07, 0xD1, 0x0C, 0x00, 0x0E, 0x17, 0xEC, 0x83, 0xC1, 0x07, 0xC1
.db 0x83, 0xC1, 0x07, 0xC1, 0xE0, 0x00, 0xF1, 0x08, 0x70, 0x00, 0x83, 0xC1, 0xC1, 0x83, 0x26, 0x64
.db 0x70, 0x0C, 0xE1, 0x83, 0x00, 0x0E, 0xF1, 0x00, 0x10, 0x08, 0x10, 0x0F, 0xE1, 0x60, 0xC6, 0x30
.db 0xFF, 0xFF, 0x04, 0x20, 0xFF, 0xFF, 0xC1, 0x83, 0x07, 0xE0, 0x83, 0xE0, 0xF0, 0x8F, 0x07, 0xC1
.db 0x83, 0xC1, 0x83, 0x87, 0x10, 0xFF, 0x10, 0x08, 0xFF, 0x08, 0x10, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF
.db 0xF7, 0xEF, 0xF7, 0xEF, 0x10, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0xFF, 0x08, 0x10, 0x08
.db 0x10, 0x08, 0x10, 0x08, 0xF7, 0xEF, 0xF7, 0xEF, 0x00, 0x00, 0xF7, 0xEF, 0x70, 0x0F, 0x70, 0x0F
.db 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0xF7, 0xCF, 0x00, 0x8F, 0x30, 0x66, 0x3E, 0x7C, 0x00, 0x00
.db 0xE0, 0x00, 0x00, 0x0E, 0x00, 0x00, 0xF7, 0xEF, 0x00, 0x00, 0xF1, 0x8F, 0x00, 0x00, 0x10, 0x08
.db 0x07, 0xC1, 0x10, 0x0C, 0x30, 0x08, 0x00, 0x87, 0x06, 0x07, 0x00, 0xC3, 0x83, 0xE0, 0x10, 0x08
.db 0x81, 0x87, 0x70, 0xEC, 0x00, 0x00, 0x00, 0x00, 0xC3, 0x00, 0x00, 0x00, 0x00, 0xC3, 0x30, 0x08
.db 0x36, 0xC3, 0xC1, 0x83, 0x83, 0x87, 0x07, 0x00, 0x83, 0xE0, 0xF1, 0x8F, 0xF1, 0xCF, 0x07, 0xCF
.db 0xF3, 0xCF, 0x30, 0x08, 0x00, 0x07, 0xB3, 0x08, 0xC1, 0x00, 0x66, 0xCC, 0x33, 0xCC, 0x07, 0xE0
.db 0xF1, 0x8F, 0x07, 0xE0, 0xF3, 0x0C, 0x30, 0x8F, 0x30, 0x08, 0x83, 0xE0, 0xE0, 0x83, 0x27, 0xE6
.db 0x30, 0x0E, 0x70, 0x0C, 0x30, 0x00, 0x30, 0x08, 0x10, 0x08, 0x10, 0x0C, 0x81, 0x81, 0x00, 0x00
.db 0x00, 0x00, 0xF0, 0x8F, 0x83, 0xC1, 0x83, 0x00, 0x83, 0xE0, 0xF3, 0xCF, 0x30, 0x08, 0x83, 0xE0
.db 0x83, 0xC1, 0x10, 0x0C, 0x00, 0x07, 0xF1, 0x0C, 0x00, 0x0E, 0x17, 0xEC, 0x83, 0xC1, 0x07, 0xC1
.db 0x83, 0xC1, 0x07, 0xC1, 0xE0, 0x00, 0xF0, 0x0E, 0x70, 0x00, 0x83, 0xC1, 0xE0, 0x83, 0x67, 0x66
.db 0x30, 0x0C, 0xE0, 0x07, 0x10, 0x0C, 0xF1, 0x00, 0x10, 0x08, 0x10, 0x0F, 0xF3, 0x6C, 0xC6, 0x30
.db 0xFF, 0xFF, 0x84, 0x21, 0xFF, 0xFF, 0x81, 0x83, 0x07, 0xE0, 0x83, 0xE0, 0xC1, 0x83, 0x07, 0xC1
.db 0x83, 0xC1, 0x83, 0xC3, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0xF7, 0x8F, 0xF1, 0xEF, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x81, 0x81, 0x00, 0x00, 0x00, 0x81, 0x81, 0xF0, 0x0F, 0x70, 0x0E
.db 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0xF7, 0xCF, 0x00, 0xCD, 0x60, 0x3C, 0x1E, 0x6C, 0x00, 0x00
.db 0xE0, 0x00, 0x00, 0x0E, 0x00, 0x00, 0xF7, 0xEF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00
.db 0x07, 0xC1, 0x10, 0x0C, 0x70, 0x00, 0x00, 0x83, 0xF7, 0xEF, 0x00, 0xC1, 0x83, 0xE0, 0x30, 0x00
.db 0x83, 0xC3, 0x00, 0xE0, 0x00, 0x00, 0x00, 0x00, 0xC3, 0x00, 0x00, 0x00, 0x00, 0xC3, 0x30, 0x08
.db 0x36, 0xC2, 0x81, 0x83, 0x83, 0xC3, 0x07, 0x00, 0x83, 0xE0, 0xC1, 0x00, 0xC1, 0x00, 0x07, 0xCF
.db 0x83, 0xC1, 0x30, 0x08, 0x00, 0x07, 0xB3, 0x0C, 0xC1, 0x00, 0x66, 0xCC, 0x13, 0xCE, 0x07, 0xE0
.db 0xF1, 0x0E, 0x07, 0xE0, 0x93, 0x0E, 0x00, 0xC7, 0x30, 0x08, 0x83, 0xE0, 0xE0, 0x03, 0x63, 0xC6
.db 0x70, 0x0E, 0x30, 0x08, 0x70, 0x00, 0x30, 0x08, 0x00, 0x0C, 0x10, 0x0C, 0x03, 0xC0, 0x00, 0x00
.db 0x00, 0x00, 0xC1, 0x83, 0x83, 0xC1, 0x83, 0x00, 0x83, 0xE0, 0xF3, 0xCF, 0x30, 0x08, 0x83, 0xE0
.db 0x83, 0xC1, 0x10, 0x0C, 0x00, 0x07, 0xD1, 0x0C, 0x00, 0x0E, 0x17, 0xEC, 0x83, 0xC1, 0x07, 0xC1
.db 0x83, 0xC1, 0x07, 0xC1, 0xE0, 0x00, 0x10, 0x8F, 0x70, 0x00, 0x83, 0xC1, 0xE0, 0x03, 0x67, 0x46
.db 0x30, 0x0C, 0xF0, 0x07, 0x30, 0x08, 0x30, 0x08, 0x10, 0x08, 0x30, 0x08, 0x36, 0xCF, 0x66, 0x31
.db 0xFF, 0xFF, 0x84, 0x21, 0xFF, 0xFF, 0xF3, 0xCF, 0x07, 0xE0, 0x83, 0xE0, 0x83, 0x83, 0x07, 0xC1
.db 0x83, 0xC1, 0x83, 0xE1, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0xF7, 0x0E, 0x70, 0xEF, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x03, 0xC0, 0x00, 0x00, 0x00, 0xC0, 0x03, 0xF0, 0x8F, 0x30, 0x0E
.db 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x81, 0x0C, 0x00, 0xCD, 0xC0, 0x3C, 0x0E, 0x6E, 0x00, 0x00
.db 0xE0, 0x00, 0x00, 0x0E, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00
.db 0x07, 0xC1, 0x10, 0x0C, 0xE0, 0x00, 0x00, 0x83, 0xF7, 0xEF, 0x00, 0xC1, 0x83, 0xE0, 0x30, 0x00
.db 0x83, 0xC1, 0x00, 0xC1, 0x00, 0x00, 0x00, 0x00, 0xF0, 0x00, 0xF7, 0xEF, 0x00, 0x0F, 0x30, 0x08
.db 0x17, 0xFE, 0xF3, 0xCF, 0x83, 0xC1, 0x07, 0x00, 0x83, 0xE0, 0xC1, 0x00, 0xC1, 0x00, 0x07, 0xC1
.db 0x83, 0xC1, 0x30, 0x08, 0x00, 0x07, 0x93, 0x0E, 0xC1, 0x00, 0x36, 0xC8, 0x03, 0xCF, 0x07, 0xE0
.db 0xC1, 0x00, 0x07, 0xE0, 0x83, 0x0E, 0x00, 0xC1, 0x30, 0x08, 0x83, 0xE0, 0x70, 0x07, 0x63, 0xC6
.db 0x60, 0x0F, 0x30, 0x08, 0xE0, 0x00, 0x30, 0x08, 0x00, 0x0C, 0x10, 0x0C, 0x03, 0xC0, 0x00, 0x00
.db 0x00, 0x00, 0x83, 0x83, 0x83, 0xC1, 0x83, 0x00, 0x83, 0xE0, 0x83, 0x00, 0x30, 0x08, 0x83, 0xE0
.db 0x83, 0xC1, 0x10, 0x0C, 0x00, 0x07, 0xD1, 0x0E, 0x00, 0x0E, 0x17, 0xEC, 0x83, 0xC1, 0x07, 0xC1
.db 0x83, 0xC1, 0x07, 0xC1, 0xE0, 0x00, 0x00, 0xC3, 0x70, 0x00, 0x83, 0xC1, 0x70, 0x07, 0x63, 0xC6
.db 0x70, 0x0E, 0x70, 0x0E, 0x70, 0x00, 0x10, 0x0C, 0x10, 0x08, 0x70, 0x00, 0x06, 0x87, 0x77, 0x7F
.db 0xFF, 0xFF, 0xC6, 0x63, 0xFF, 0xFF, 0xF3, 0xCF, 0x83, 0xC1, 0x83, 0xE0, 0x83, 0x83, 0x07, 0xC1
.db 0x83, 0xC1, 0x83, 0xE0, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0xF7, 0x08, 0x10, 0xEF, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x02, 0x40, 0x00, 0x00, 0x00, 0x40, 0x02, 0xF1, 0x8F, 0x30, 0x0C
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x81, 0x0C, 0x00, 0xCD, 0x81, 0x3C, 0x0E, 0xE7, 0x00, 0x00
.db 0xE0, 0x00, 0x00, 0x0E, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x00
.db 0x83, 0x83, 0x10, 0x0C, 0xC0, 0x00, 0x00, 0x83, 0x00, 0x07, 0x00, 0xC1, 0xC1, 0xE0, 0x60, 0x00
.db 0x83, 0xC1, 0x00, 0xC1, 0x00, 0x00, 0x00, 0x00, 0x30, 0x0C, 0xF7, 0xEF, 0x30, 0x0C, 0x00, 0x00
.db 0x13, 0xFC, 0xF3, 0xCF, 0x83, 0xC1, 0x83, 0x00, 0x83, 0xC1, 0xC1, 0x00, 0xC1, 0x00, 0x83, 0xC1
.db 0x83, 0xC1, 0x30, 0x08, 0x00, 0x07, 0x83, 0x0F, 0xC1, 0x00, 0x36, 0xC8, 0x03, 0xC7, 0x83, 0xC1
.db 0xC1, 0x00, 0x83, 0xC1, 0x83, 0x0F, 0x00, 0xC1, 0x30, 0x08, 0x83, 0xE0, 0x70, 0x07, 0x63, 0xC6
.db 0xC0, 0x87, 0x30, 0x08, 0xC1, 0x00, 0x30, 0x08, 0x00, 0x06, 0x10, 0x0C, 0x06, 0x60, 0x00, 0x00
.db 0x00, 0x00, 0x83, 0x83, 0x83, 0xC1, 0xC3, 0x00, 0x83, 0xE0, 0x83, 0x00, 0x30, 0x08, 0x83, 0xE0
.db 0x83, 0xC1, 0x10, 0x0C, 0x00, 0x07, 0xC1, 0x0F, 0x00, 0x0E, 0x17, 0xEC, 0x83, 0xC1, 0x07, 0xC1
.db 0x83, 0xC1, 0x07, 0xC1, 0xE0, 0x00, 0x00, 0xC1, 0x70, 0x00, 0x83, 0xC1, 0x70, 0x07, 0x43, 0xC6
.db 0xE0, 0x0F, 0x70, 0x0E, 0xE0, 0x00, 0x10, 0x0C, 0x10, 0x08, 0x70, 0x00, 0x00, 0x00, 0x13, 0x6E
.db 0xFF, 0xFF, 0x42, 0x42, 0xFF, 0xFF, 0x07, 0xC1, 0x83, 0xC1, 0xC3, 0xE1, 0x83, 0x83, 0x83, 0x83
.db 0x83, 0xC3, 0x83, 0xE0, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0xF7, 0x00, 0x00, 0xEF, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF1, 0x8F, 0x10, 0x0C
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x81, 0x0C, 0x00, 0xCD, 0x81, 0x3C, 0x0F, 0xC7, 0x00, 0x00
.db 0x70, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x10, 0x08, 0x30, 0x0C, 0x00, 0x00, 0x30, 0x0C, 0x60, 0x00
.db 0x83, 0x83, 0x10, 0x0C, 0xC1, 0x00, 0x00, 0x87, 0x00, 0x07, 0x00, 0xC3, 0xC1, 0xC1, 0x60, 0x00
.db 0x83, 0xC1, 0x00, 0x83, 0x30, 0x0C, 0x30, 0x0C, 0x00, 0x0F, 0x00, 0x00, 0xF0, 0x00, 0x00, 0x00
.db 0x83, 0x00, 0x07, 0xC1, 0x83, 0xC1, 0xC3, 0x00, 0x83, 0xC1, 0xC1, 0x00, 0xC1, 0x00, 0xC3, 0xC1
.db 0x83, 0xC1, 0x30, 0x08, 0x00, 0x07, 0x83, 0x87, 0xC1, 0x00, 0x36, 0xC8, 0x03, 0xC7, 0x83, 0xC1
.db 0xC1, 0x00, 0x83, 0xC1, 0x83, 0x87, 0x00, 0xC1, 0x30, 0x08, 0xC3, 0xE1, 0x70, 0x0E, 0x43, 0xC7
.db 0x81, 0xC3, 0x30, 0x08, 0x83, 0x00, 0x30, 0x08, 0x00, 0x06, 0x10, 0x0C, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x83, 0x83, 0x83, 0x83, 0xC1, 0x00, 0xC3, 0xE1, 0xC1, 0x00, 0x30, 0x08, 0xC3, 0xE1
.db 0x83, 0xC1, 0x10, 0x0C, 0x00, 0x07, 0xC1, 0x07, 0x00, 0x0E, 0x17, 0xEC, 0x83, 0xC1, 0x83, 0x83
.db 0x83, 0x83, 0x87, 0xC3, 0xE0, 0x00, 0x00, 0xC1, 0x70, 0x00, 0x83, 0xC3, 0x70, 0x06, 0xC3, 0xC3
.db 0xC0, 0x07, 0x30, 0x0C, 0xC1, 0x00, 0x10, 0x0C, 0x10, 0x08, 0x70, 0x00, 0x00, 0x00, 0x83, 0xE0
.db 0xFF, 0xFF, 0x31, 0x8C, 0xFF, 0xFF, 0x07, 0xE0, 0xC1, 0x83, 0xC1, 0xC1, 0xC3, 0x87, 0xC3, 0x87
.db 0xC3, 0xC7, 0x93, 0xE0, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0xC7, 0x00, 0x00, 0xE3, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF3, 0xCF, 0x10, 0x0C
.db 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x81, 0x0C, 0x81, 0x8D, 0x03, 0x3C, 0x87, 0xC3, 0x00, 0x00
.db 0x70, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x10, 0x08, 0x30, 0x0C, 0x00, 0x00, 0x30, 0x0C, 0xC0, 0x00
.db 0xC1, 0x07, 0x10, 0x0C, 0x83, 0x00, 0x01, 0x0F, 0x00, 0x07, 0x80, 0x87, 0xE0, 0xC1, 0xE0, 0x00
.db 0xC1, 0x83, 0x01, 0x87, 0x30, 0x0C, 0x30, 0x0C, 0x00, 0xC3, 0x00, 0x00, 0xC3, 0x00, 0x30, 0x08
.db 0xC1, 0x01, 0x07, 0xE0, 0x83, 0xC3, 0xE1, 0x40, 0x83, 0x87, 0xC1, 0x00, 0xC1, 0x00, 0xE1, 0xC1
.db 0x83, 0xC1, 0x30, 0x08, 0x02, 0x0E, 0x83, 0xC3, 0xC1, 0x00, 0x06, 0xC0, 0x03, 0xC3, 0xC1, 0x83
.db 0xC1, 0x00, 0xC1, 0x83, 0x83, 0xC3, 0x03, 0x83, 0x30, 0x08, 0xC1, 0xC1, 0x30, 0x0E, 0xC3, 0xC3
.db 0x83, 0xC1, 0x30, 0x08, 0x07, 0x00, 0x30, 0x08, 0x00, 0x03, 0x10, 0x0C, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0xC3, 0x87, 0xC3, 0x87, 0xF1, 0x40, 0xC1, 0xE3, 0xE1, 0x40, 0x30, 0x08, 0xC1, 0xE3
.db 0x83, 0xC1, 0x10, 0x0C, 0x00, 0x07, 0xC1, 0x87, 0x00, 0x0E, 0x17, 0xEC, 0x83, 0xC1, 0xC3, 0x87
.db 0xC3, 0x87, 0x83, 0xC7, 0xE0, 0x00, 0x81, 0xC3, 0x70, 0x08, 0xC3, 0xC7, 0x30, 0x0E, 0xC3, 0xC3
.db 0xC1, 0x87, 0x30, 0x0C, 0x83, 0x00, 0x10, 0x0C, 0x10, 0x08, 0x70, 0x00, 0x00, 0x00, 0xC1, 0xC1
.db 0xFF, 0xFF, 0xC0, 0x03, 0xFF, 0xFF, 0x07, 0xE0, 0xF0, 0x0F, 0xF0, 0x8F, 0xF1, 0xED, 0xF1, 0x0F
.db 0xF1, 0xCD, 0x93, 0xCF, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0x07, 0x00, 0x00, 0xE0, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x00, 0x00, 0xF7, 0xEF
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF3, 0xCF, 0x00, 0x08
.db 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x13, 0x08, 0xF1, 0x8F, 0x06, 0x66, 0xF3, 0xEF, 0x00, 0x00
.db 0x70, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x10, 0x08, 0x30, 0x0C, 0x00, 0x00, 0x30, 0x0C, 0xC0, 0x00
.db 0xF0, 0x0E, 0xF3, 0xEF, 0xF3, 0x8F, 0xF1, 0x0E, 0x00, 0x07, 0xF0, 0x0F, 0xF0, 0x8F, 0xC0, 0x00
.db 0xF0, 0x0F, 0xF1, 0x0F, 0x30, 0x0C, 0x30, 0x0C, 0x00, 0xE0, 0x00, 0x00, 0x07, 0x00, 0x30, 0x08
.db 0xF0, 0x0F, 0x07, 0xE0, 0xF3, 0x8F, 0xF0, 0xCF, 0xF3, 0x0F, 0xF1, 0xEF, 0xC1, 0x00, 0xF0, 0xCF
.db 0x83, 0xC1, 0xF3, 0x8F, 0xF3, 0x0C, 0x83, 0xE1, 0xF1, 0xCF, 0x06, 0xC0, 0x03, 0xC1, 0xF0, 0x0F
.db 0xC1, 0x00, 0xF0, 0x0F, 0x83, 0xC1, 0xF3, 0x8F, 0x30, 0x08, 0xF0, 0x8F, 0x30, 0x0E, 0xC3, 0x83
.db 0x07, 0xE1, 0x30, 0x08, 0xF7, 0xCF, 0x30, 0x08, 0x00, 0x03, 0x10, 0x0C, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0xF1, 0xED, 0xF3, 0x0F, 0xF0, 0xCF, 0xF0, 0xEE, 0xF0, 0xCF, 0x30, 0x08, 0xF0, 0xEE
.db 0x83, 0xC1, 0x10, 0x0C, 0x00, 0x07, 0xC1, 0xC3, 0x00, 0x0E, 0x17, 0xEC, 0x83, 0xC1, 0xF1, 0x0F
.db 0xF3, 0x0F, 0xF1, 0xCD, 0xE0, 0x00, 0xF1, 0x8F, 0x30, 0xCF, 0xF1, 0xCD, 0x30, 0x0E, 0xC3, 0x83
.db 0x83, 0xC3, 0x30, 0x08, 0xF3, 0xCF, 0x30, 0x08, 0x10, 0x08, 0x30, 0x08, 0x00, 0x00, 0xF0, 0x8F
.db 0xFF, 0xFF, 0x70, 0x0E, 0xFF, 0xFF, 0x0E, 0x70, 0x70, 0x0E, 0x70, 0x0F, 0xF0, 0xE1, 0x70, 0x0C
.db 0xF0, 0xC1, 0x83, 0x8F, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0x04, 0x00, 0x00, 0x20, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x00, 0x00, 0xF7, 0xEF
.db 0x10, 0x08, 0xD0, 0x0B, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xEF, 0x00, 0x08
.db 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x13, 0x08, 0x70, 0x0F, 0x0C, 0xC3, 0xF0, 0xFC, 0x00, 0x00
.db 0x30, 0x08, 0x30, 0x08, 0x00, 0x00, 0x10, 0x08, 0x30, 0x0C, 0x00, 0x00, 0x30, 0x0C, 0x81, 0x00
.db 0x70, 0x0C, 0xF3, 0xEF, 0xF3, 0x8F, 0xF1, 0x0C, 0x00, 0x07, 0xF0, 0x0C, 0x30, 0x0E, 0xC0, 0x00
.db 0x70, 0x0E, 0xF0, 0x0C, 0x30, 0x0C, 0x30, 0x0C, 0x00, 0x20, 0x00, 0x00, 0x04, 0x00, 0x30, 0x08
.db 0x30, 0x0E, 0x0E, 0x70, 0xF3, 0x0E, 0x30, 0x8F, 0xF3, 0x0C, 0xF1, 0xEF, 0xC1, 0x00, 0x30, 0x8F
.db 0x83, 0xC1, 0xF3, 0x8F, 0xF3, 0x08, 0x83, 0xF1, 0xF1, 0xCF, 0x06, 0xC0, 0x03, 0xC1, 0x70, 0x0E
.db 0xC1, 0x00, 0x70, 0x0E, 0x83, 0xE1, 0xF0, 0x0E, 0x30, 0x08, 0x70, 0x0F, 0x10, 0x0C, 0xC3, 0x83
.db 0x0E, 0xF0, 0x30, 0x08, 0xF7, 0xCF, 0x30, 0x08, 0x00, 0x81, 0x10, 0x0C, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0xF0, 0xE1, 0x33, 0x0E, 0x30, 0x8F, 0x70, 0xEC, 0x30, 0x8F, 0x30, 0x08, 0x70, 0xEC
.db 0x83, 0xC1, 0x10, 0x0C, 0x00, 0x07, 0xC1, 0xE1, 0x00, 0x0E, 0x17, 0xEC, 0x83, 0xC1, 0x70, 0x0C
.db 0x93, 0x0E, 0xF0, 0xC1, 0xE0, 0x00, 0xF0, 0x0E, 0x10, 0xCF, 0xF0, 0xC1, 0x10, 0x0C, 0x81, 0x83
.db 0x07, 0xE1, 0x10, 0x08, 0xF3, 0xCF, 0x30, 0x08, 0x10, 0x08, 0x30, 0x08, 0x00, 0x00, 0x70, 0x0F
.db 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x10, 0x08, 0x70, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x10, 0x0C, 0x70, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x81, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x87, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x08, 0x00, 0x81, 0x10, 0x0C, 0x00, 0x00, 0xFF, 0xFF
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xE0
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x83, 0x00, 0x00, 0xC1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x30, 0x08, 0x00, 0x00, 0x30, 0x08, 0x10, 0x08, 0x30, 0x08, 0x00, 0x00, 0x00, 0x00
.db 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x10, 0x08, 0x30, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x0F, 0xE1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0xE1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x08, 0x00, 0xC0, 0x10, 0x0C, 0x00, 0x00, 0xFF, 0xFF
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC1
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x83, 0x00, 0x00, 0xC1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x30, 0x00, 0x00, 0x00, 0x30, 0x0C, 0x10, 0x08, 0x70, 0x08, 0x00, 0x00, 0x00, 0x00
.db 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x87, 0xC3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0xCF, 0x00, 0xC0, 0xF3, 0x0C, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x81, 0xC3
.db 0x00, 0x00, 0x00, 0x00, 0x02, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x83, 0x00, 0x00, 0xC1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x70, 0x00, 0x00, 0x00, 0x10, 0x8F, 0x10, 0x08, 0xF3, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x10, 0x08, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x10, 0x08, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x81, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0xCF, 0x00, 0x60, 0xF3, 0x0C, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF1, 0x8F
.db 0x00, 0x00, 0x00, 0x00, 0xF3, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x83, 0x00, 0x00, 0xC1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0xE3, 0x00, 0x00, 0x00, 0x00, 0x8F, 0x10, 0x08, 0xE3, 0x00, 0x00, 0x00, 0x00, 0x00
.endif

.if (CSize==18)
font:
; Terminal 14; H=18, B=12
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x60, 0x81, 0x60, 0x81, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C
.db 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x81, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x06, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x8F
.db 0x10, 0x0E, 0x10, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x0E
.db 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x87, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x0C, 0x30, 0x03, 0x00, 0x00, 0x00, 0x0C, 0x20, 0x81, 0x30, 0x0C, 0x00, 0x0C
.db 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x81
.db 0x10, 0x0E, 0x00, 0x0C, 0x10, 0x0E, 0x10, 0x0E, 0x00, 0x0C, 0x70, 0x8F, 0x00, 0x87, 0x70, 0x8F
.db 0x10, 0x0E, 0x10, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x0F
.db 0x10, 0x0F, 0x10, 0x0E, 0x70, 0x0E, 0x10, 0x0E, 0x70, 0x0E, 0x70, 0x8F, 0x70, 0x8F, 0x10, 0x0E
.db 0x60, 0x81, 0x70, 0x8F, 0x00, 0x81, 0x60, 0x81, 0x60, 0x00, 0x60, 0x81, 0x60, 0x81, 0x10, 0x0E
.db 0x70, 0x0E, 0x10, 0x0E, 0x70, 0x0E, 0x10, 0x0E, 0x70, 0x8F, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x70, 0x8F, 0x10, 0x0E, 0x60, 0x00, 0x10, 0x0E, 0x00, 0x0C, 0x00, 0x00
.db 0x00, 0x0C, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x00, 0x81, 0x00, 0x00, 0x00, 0x0F, 0x00, 0x00
.db 0x60, 0x00, 0x00, 0x0C, 0x00, 0x06, 0x60, 0x00, 0x30, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x0C, 0x30, 0x08, 0x10, 0x89, 0x00, 0x0C
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x8F, 0x70, 0x8F
.db 0x30, 0x03, 0x30, 0x03, 0x60, 0x81, 0x30, 0x03, 0x00, 0x00, 0x60, 0x81, 0x30, 0x0F, 0x30, 0x0F
.db 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x10, 0xCF, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x10, 0x0E, 0x30, 0x03, 0x30, 0x03, 0x00, 0x0C, 0x70, 0x01, 0x60, 0x06, 0x00, 0x0C
.db 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x81
.db 0x30, 0x03, 0x10, 0x0C, 0x30, 0x03, 0x30, 0x03, 0x00, 0x0C, 0x60, 0x00, 0x00, 0x0C, 0x00, 0x81
.db 0x30, 0x03, 0x30, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x83
.db 0x30, 0x81, 0x30, 0x03, 0x60, 0x03, 0x30, 0x03, 0x60, 0x03, 0x60, 0x00, 0x60, 0x00, 0x30, 0x03
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x81, 0x60, 0x81, 0x60, 0x00, 0x60, 0x81, 0x60, 0x81, 0x30, 0x03
.db 0x60, 0x03, 0x30, 0x03, 0x60, 0x03, 0x30, 0x03, 0x00, 0x0C, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x00, 0x81, 0x10, 0x08, 0x60, 0x00, 0x00, 0x06, 0x10, 0x0F, 0x00, 0x00
.db 0x00, 0x0C, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x00, 0x81, 0x00, 0x00, 0x10, 0x89, 0x00, 0x00
.db 0x60, 0x00, 0x00, 0x0C, 0x00, 0x06, 0x60, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x60, 0x06, 0x00, 0x0C
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x30, 0x03, 0x60, 0x81, 0x60, 0x81, 0x30, 0x81, 0x70, 0x8F
.db 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x10, 0xCF, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x10, 0x0E, 0x30, 0x03, 0x30, 0x03, 0x30, 0x0F, 0x50, 0x03, 0x40, 0x02, 0x00, 0x04
.db 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03
.db 0x60, 0x81, 0x70, 0x0C, 0x60, 0x81, 0x60, 0x81, 0x10, 0x08, 0x60, 0x00, 0x10, 0x08, 0x00, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x60, 0x00, 0x60, 0x81
.db 0x60, 0xC0, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x03, 0x60, 0x00, 0x60, 0x00, 0x60, 0x81
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x81, 0x60, 0x03, 0x60, 0x00, 0x60, 0x81, 0x70, 0x81, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x00, 0x0C, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x00, 0x81, 0x10, 0x08, 0x30, 0x00, 0x00, 0x06, 0x70, 0x83, 0x00, 0x00
.db 0x00, 0x08, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x00, 0x81, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00
.db 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x10, 0x0E
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x00, 0x00, 0x60, 0x81, 0x00, 0x00, 0x30, 0x81, 0x00, 0x0C
.db 0x00, 0x0C, 0x00, 0x80, 0x10, 0x00, 0x00, 0xEF, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x10, 0x0E, 0x00, 0x00, 0x30, 0x03, 0x60, 0x8D, 0x50, 0x02, 0x40, 0x02, 0x00, 0x08
.db 0x10, 0x08, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03
.db 0x60, 0x83, 0x00, 0x0C, 0x60, 0x81, 0x60, 0x81, 0x10, 0x08, 0x60, 0x00, 0x30, 0x00, 0x00, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x30, 0x00, 0x00, 0x81
.db 0x60, 0xC0, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x00, 0x60, 0x00, 0x60, 0x81
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x81, 0x60, 0x07, 0x60, 0x00, 0x70, 0x83, 0x70, 0x81, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x00, 0x0C, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x00, 0x03, 0x10, 0x08, 0x30, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x04, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x00, 0x81, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00
.db 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x30, 0x03
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x81, 0x00, 0x0C
.db 0x00, 0x0C, 0x00, 0xC0, 0x30, 0x00, 0x00, 0xF7, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x10, 0x0E, 0x00, 0x00, 0x30, 0x03, 0x60, 0x8D, 0x70, 0x06, 0x60, 0x06, 0x00, 0x00
.db 0x10, 0x08, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06
.db 0x60, 0x83, 0x00, 0x0C, 0x00, 0x81, 0x00, 0x81, 0x10, 0x08, 0x60, 0x00, 0x30, 0x00, 0x00, 0x03
.db 0x60, 0x81, 0x60, 0x81, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x10, 0x08, 0x00, 0x83
.db 0x60, 0xC7, 0x60, 0x81, 0x60, 0x81, 0x60, 0x00, 0x60, 0x81, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x81, 0x60, 0x06, 0x60, 0x00, 0x70, 0x83, 0x70, 0x89, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x00, 0x00, 0x0C, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81
.db 0x30, 0x03, 0x60, 0x81, 0x00, 0x03, 0x10, 0x08, 0x10, 0x08, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x00, 0x81, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00
.db 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x30, 0x03
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x10, 0x0F, 0x10, 0x0E, 0x60, 0x81, 0x30, 0x03, 0x00, 0x0C
.db 0x00, 0x0C, 0x00, 0xE0, 0x70, 0x00, 0x00, 0x06, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x10, 0x0E, 0x00, 0x00, 0x70, 0x8F, 0x70, 0x0C, 0x20, 0x04, 0x30, 0x0C, 0x00, 0x00
.db 0x10, 0x08, 0x00, 0x06, 0x30, 0x03, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06
.db 0x60, 0x85, 0x00, 0x0C, 0x00, 0x81, 0x00, 0x81, 0x30, 0x00, 0x70, 0x0E, 0x60, 0x00, 0x00, 0x03
.db 0x30, 0x03, 0x60, 0x81, 0x00, 0x0C, 0x00, 0x0C, 0x10, 0x08, 0x70, 0x8F, 0x00, 0x0C, 0x00, 0x03
.db 0x60, 0xCC, 0x60, 0x81, 0x60, 0x03, 0x60, 0x00, 0x60, 0x81, 0x60, 0x00, 0x60, 0x00, 0x60, 0x00
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x81, 0x60, 0x0C, 0x60, 0x00, 0x70, 0x83, 0x60, 0x89, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x70, 0x08, 0x00, 0x0C, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81
.db 0x30, 0x03, 0x60, 0x81, 0x00, 0x06, 0x10, 0x08, 0x10, 0x08, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x10, 0x0F, 0x60, 0x0E, 0x10, 0x0F, 0x10, 0x8D, 0x10, 0x0E, 0x70, 0x0F, 0x10, 0x8D
.db 0x60, 0x0E, 0x30, 0x0C, 0x10, 0x0E, 0x60, 0x81, 0x00, 0x0C, 0x70, 0x03, 0x60, 0x0E, 0x10, 0x0E
.db 0x60, 0x0E, 0x10, 0x8D, 0x60, 0x07, 0x30, 0x0F, 0x30, 0x0F, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x70, 0x8F, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x60, 0x81
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x20, 0x81, 0x30, 0x03, 0x60, 0x81, 0x70, 0x0E, 0x00, 0x0C
.db 0x00, 0x0C, 0xF0, 0xFF, 0xF0, 0xFF, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x30, 0x03, 0x10, 0x0C, 0x00, 0x0C, 0x10, 0x08, 0x00, 0x00
.db 0x10, 0x08, 0x00, 0x06, 0x10, 0x0E, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C
.db 0x60, 0x85, 0x00, 0x0C, 0x00, 0x03, 0x10, 0x0F, 0x30, 0x00, 0x00, 0x03, 0x70, 0x0E, 0x00, 0x03
.db 0x10, 0x0E, 0x30, 0x81, 0x00, 0x0C, 0x00, 0x0C, 0x30, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x06
.db 0x60, 0xCC, 0x60, 0x81, 0x70, 0x0E, 0x60, 0x00, 0x60, 0x81, 0x70, 0x0F, 0x60, 0x00, 0x60, 0x00
.db 0x70, 0x8F, 0x00, 0x0C, 0x00, 0x81, 0x70, 0x08, 0x60, 0x00, 0x70, 0x8F, 0x60, 0x8D, 0x60, 0x81
.db 0x60, 0x03, 0x60, 0x81, 0x60, 0x03, 0x30, 0x0C, 0x00, 0x0C, 0x60, 0x81, 0x30, 0x03, 0x60, 0x8D
.db 0x10, 0x0E, 0x30, 0x03, 0x00, 0x0C, 0x10, 0x08, 0x00, 0x0C, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x20, 0x81, 0x70, 0x03, 0x30, 0x81, 0x30, 0x83, 0x30, 0x03, 0x10, 0x08, 0x30, 0x83
.db 0x70, 0x03, 0x00, 0x0C, 0x00, 0x06, 0x60, 0x03, 0x00, 0x0C, 0x70, 0x8F, 0x70, 0x03, 0x30, 0x03
.db 0x70, 0x03, 0x20, 0x83, 0x70, 0x8F, 0x60, 0x81, 0x00, 0x0C, 0x60, 0x81, 0x60, 0x81, 0x60, 0x8D
.db 0x60, 0x81, 0x60, 0x81, 0x00, 0x81, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x60, 0x81
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x00, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x03, 0x00, 0x0C
.db 0x00, 0x0C, 0xF0, 0xFF, 0xF0, 0xFF, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x30, 0x03, 0x00, 0x0E, 0x00, 0x08, 0x30, 0x8C, 0x00, 0x00
.db 0x10, 0x08, 0x00, 0x06, 0x70, 0x8F, 0x70, 0x8F, 0x00, 0x00, 0x70, 0x8F, 0x00, 0x00, 0x00, 0x0C
.db 0x60, 0x89, 0x00, 0x0C, 0x00, 0x06, 0x00, 0x81, 0x30, 0x06, 0x00, 0x81, 0x60, 0x03, 0x00, 0x06
.db 0x30, 0x03, 0x10, 0x8F, 0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x06
.db 0x60, 0xCC, 0x60, 0x81, 0x60, 0x03, 0x60, 0x00, 0x60, 0x81, 0x60, 0x00, 0x70, 0x0F, 0x60, 0x87
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x81, 0x70, 0x08, 0x60, 0x00, 0x60, 0x8D, 0x60, 0x85, 0x60, 0x81
.db 0x70, 0x0E, 0x60, 0x81, 0x70, 0x0E, 0x00, 0x0F, 0x00, 0x0C, 0x60, 0x81, 0x30, 0x03, 0x60, 0x8D
.db 0x10, 0x0E, 0x30, 0x0F, 0x10, 0x08, 0x10, 0x08, 0x00, 0x0C, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x81, 0x60, 0x81, 0x60, 0x00, 0x60, 0x81, 0x60, 0x81, 0x10, 0x08, 0x60, 0x81
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x06, 0x60, 0x06, 0x00, 0x0C, 0x60, 0x8D, 0x60, 0x81, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x70, 0x00, 0x60, 0x00, 0x00, 0x0C, 0x60, 0x81, 0x60, 0x81, 0x60, 0x8D
.db 0x30, 0x03, 0x60, 0x81, 0x00, 0x03, 0x10, 0x08, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x60, 0x81
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x8F
.db 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x70, 0x8F, 0x60, 0x81, 0x60, 0x81, 0x30, 0x8F, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x00, 0x0C
.db 0x00, 0x0C, 0x00, 0xE0, 0x70, 0x00, 0x10, 0x08, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x70, 0x8F, 0x00, 0x8F, 0x10, 0x09, 0x60, 0x87, 0x00, 0x00
.db 0x10, 0x08, 0x00, 0x06, 0x10, 0x0E, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0x60, 0x89, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x81, 0x60, 0x06, 0x00, 0x81, 0x60, 0x81, 0x00, 0x06
.db 0x60, 0x81, 0x00, 0x81, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x70, 0x8F, 0x00, 0x06, 0x00, 0x0C
.db 0x60, 0xCD, 0x70, 0x8F, 0x60, 0x81, 0x60, 0x00, 0x60, 0x81, 0x60, 0x00, 0x60, 0x00, 0x60, 0x81
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x81, 0x60, 0x0C, 0x60, 0x00, 0x60, 0x8D, 0x60, 0x87, 0x60, 0x81
.db 0x60, 0x00, 0x60, 0x81, 0x60, 0x06, 0x00, 0x87, 0x00, 0x0C, 0x60, 0x81, 0x30, 0x03, 0x60, 0x8D
.db 0x30, 0x03, 0x10, 0x0E, 0x10, 0x08, 0x10, 0x08, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x30, 0x8F, 0x60, 0x81, 0x60, 0x00, 0x60, 0x81, 0x60, 0x81, 0x10, 0x08, 0x60, 0x81
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x06, 0x60, 0x0C, 0x00, 0x0C, 0x60, 0x8D, 0x60, 0x81, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x00, 0x30, 0x08, 0x00, 0x0C, 0x60, 0x81, 0x60, 0x81, 0x60, 0x8D
.db 0x30, 0x0F, 0x60, 0x81, 0x00, 0x06, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x60, 0x81
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x8F, 0x70, 0x8F
.db 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x00, 0x0C
.db 0x00, 0x0C, 0x00, 0xC0, 0x30, 0x00, 0x10, 0x08, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x30, 0x03, 0x60, 0x8D, 0x10, 0x83, 0x40, 0x03, 0x00, 0x00
.db 0x10, 0x08, 0x00, 0x06, 0x30, 0x03, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08
.db 0x70, 0x81, 0x00, 0x0C, 0x10, 0x08, 0x00, 0x81, 0x60, 0x06, 0x00, 0x81, 0x60, 0x81, 0x00, 0x06
.db 0x60, 0x81, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x0C
.db 0x60, 0xC6, 0x60, 0x81, 0x60, 0x81, 0x60, 0x00, 0x60, 0x81, 0x60, 0x00, 0x60, 0x00, 0x60, 0x81
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x81, 0x60, 0x06, 0x60, 0x00, 0x60, 0x8D, 0x60, 0x83, 0x60, 0x81
.db 0x60, 0x00, 0x60, 0x81, 0x60, 0x03, 0x00, 0x81, 0x00, 0x0C, 0x60, 0x81, 0x10, 0x02, 0x30, 0x03
.db 0x30, 0x03, 0x00, 0x0C, 0x30, 0x00, 0x10, 0x08, 0x00, 0x06, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x60, 0x81, 0x60, 0x81, 0x60, 0x00, 0x60, 0x81, 0x70, 0x8F, 0x10, 0x08, 0x60, 0x81
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x06, 0x70, 0x08, 0x00, 0x0C, 0x60, 0x8D, 0x60, 0x81, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x00, 0x00, 0x0C, 0x00, 0x0C, 0x60, 0x81, 0x60, 0x81, 0x60, 0x8D
.db 0x00, 0x0C, 0x60, 0x81, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x60, 0x81
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x00, 0x0C
.db 0x00, 0x0C, 0x00, 0x80, 0x10, 0x00, 0x30, 0x00, 0x00, 0xF7, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x03, 0x60, 0x8D, 0x30, 0x82, 0x40, 0x02, 0x00, 0x00
.db 0x10, 0x08, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00
.db 0x70, 0x81, 0x00, 0x0C, 0x30, 0x00, 0x60, 0x81, 0x60, 0x06, 0x60, 0x81, 0x60, 0x81, 0x00, 0x0C
.db 0x60, 0x81, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x10, 0x08, 0x00, 0x00
.db 0x60, 0x00, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x00, 0x60, 0x00, 0x60, 0x81
.db 0x60, 0x81, 0x00, 0x0C, 0x60, 0x81, 0x60, 0x07, 0x60, 0x00, 0x60, 0x81, 0x60, 0x83, 0x60, 0x81
.db 0x60, 0x00, 0x60, 0x81, 0x60, 0x03, 0x60, 0x81, 0x00, 0x0C, 0x60, 0x81, 0x10, 0x0E, 0x30, 0x03
.db 0x60, 0x81, 0x00, 0x0C, 0x30, 0x00, 0x10, 0x08, 0x00, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x60, 0x81, 0x60, 0x81, 0x60, 0x00, 0x60, 0x81, 0x60, 0x00, 0x10, 0x08, 0x60, 0x81
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x06, 0x70, 0x0C, 0x00, 0x0C, 0x60, 0x8D, 0x60, 0x81, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x00, 0x00, 0x07, 0x00, 0x0C, 0x60, 0x81, 0x30, 0x03, 0x60, 0x8D
.db 0x30, 0x0F, 0x30, 0x03, 0x10, 0x08, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x60, 0x81
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x70, 0x0F, 0x00, 0x0C
.db 0x70, 0x8F, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00, 0xEF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x03, 0x30, 0x0F, 0x20, 0x82, 0x40, 0x03, 0x00, 0x00
.db 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00
.db 0x60, 0x81, 0x00, 0x0C, 0x60, 0x00, 0x60, 0x81, 0x70, 0x8F, 0x60, 0x81, 0x60, 0x81, 0x00, 0x0C
.db 0x60, 0x81, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x30, 0x00, 0x00, 0x00
.db 0x60, 0x00, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81, 0x60, 0x03, 0x60, 0x00, 0x60, 0x00, 0x60, 0x81
.db 0x60, 0x81, 0x00, 0x0C, 0x60, 0x81, 0x60, 0x03, 0x60, 0x00, 0x60, 0x81, 0x60, 0x81, 0x60, 0x81
.db 0x60, 0x00, 0x60, 0x81, 0x60, 0x03, 0x60, 0x81, 0x00, 0x0C, 0x60, 0x81, 0x10, 0x0E, 0x30, 0x03
.db 0x60, 0x81, 0x00, 0x0C, 0x60, 0x00, 0x10, 0x08, 0x00, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x60, 0x81, 0x60, 0x81, 0x60, 0x00, 0x60, 0x81, 0x60, 0x00, 0x10, 0x08, 0x30, 0x83
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x06, 0x60, 0x06, 0x00, 0x0C, 0x60, 0x8D, 0x60, 0x81, 0x60, 0x81
.db 0x60, 0x81, 0x60, 0x81, 0x60, 0x00, 0x00, 0x81, 0x00, 0x0C, 0x60, 0x81, 0x10, 0x02, 0x30, 0x03
.db 0x30, 0x03, 0x30, 0x03, 0x30, 0x00, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x60, 0x81
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x60, 0x81, 0x30, 0x03, 0x30, 0x03, 0x60, 0x83, 0x30, 0x03, 0x60, 0x83, 0x60, 0x00, 0x00, 0x0C
.db 0x30, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0xE7, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x30, 0x03, 0x00, 0x0C, 0x60, 0x83, 0x60, 0x87, 0x00, 0x00
.db 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x0C, 0x60, 0x00
.db 0x30, 0x03, 0x00, 0x0C, 0x60, 0x00, 0x30, 0x03, 0x00, 0x06, 0x30, 0x03, 0x30, 0x03, 0x00, 0x0C
.db 0x30, 0x03, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x03, 0x00, 0x00, 0x60, 0x00, 0x00, 0x0C
.db 0x30, 0xC0, 0x60, 0x81, 0x60, 0x03, 0x30, 0x03, 0x60, 0x03, 0x60, 0x00, 0x60, 0x00, 0x30, 0x03
.db 0x60, 0x81, 0x00, 0x0C, 0x30, 0x03, 0x60, 0x81, 0x60, 0x00, 0x60, 0x81, 0x60, 0x81, 0x30, 0x03
.db 0x60, 0x00, 0x30, 0x03, 0x60, 0x03, 0x30, 0x03, 0x00, 0x0C, 0x30, 0x03, 0x00, 0x0C, 0x30, 0x03
.db 0x60, 0x81, 0x00, 0x0C, 0x60, 0x00, 0x10, 0x08, 0x00, 0x81, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x60, 0x83, 0x70, 0x03, 0x30, 0x81, 0x30, 0x83, 0x30, 0x81, 0x10, 0x08, 0x10, 0x8D
.db 0x60, 0x81, 0x00, 0x0C, 0x00, 0x06, 0x60, 0x03, 0x00, 0x0C, 0x60, 0x8D, 0x60, 0x81, 0x30, 0x03
.db 0x70, 0x03, 0x20, 0x83, 0x60, 0x00, 0x60, 0x81, 0x00, 0x0C, 0x60, 0x83, 0x10, 0x0E, 0x30, 0x03
.db 0x60, 0x81, 0x10, 0x0E, 0x60, 0x00, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x70, 0x8F
.db 0x00, 0x00, 0x00, 0x00, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x60, 0x81, 0x10, 0x0E, 0x10, 0x0E, 0x30, 0x8D, 0x10, 0x0E, 0x30, 0x8D, 0x60, 0x00, 0x00, 0x0C
.db 0x10, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0xC1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x40, 0x01, 0x30, 0x8C, 0x00, 0x00
.db 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x0C, 0x60, 0x00
.db 0x10, 0x0E, 0x70, 0x8F, 0x70, 0x8F, 0x10, 0x0E, 0x00, 0x06, 0x10, 0x0E, 0x10, 0x0E, 0x00, 0x0C
.db 0x10, 0x0E, 0x70, 0x08, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C
.db 0x10, 0x8F, 0x60, 0x81, 0x70, 0x0E, 0x10, 0x0E, 0x70, 0x0E, 0x70, 0x8F, 0x60, 0x00, 0x10, 0x0E
.db 0x60, 0x81, 0x70, 0x8F, 0x10, 0x0E, 0x60, 0x81, 0x70, 0x8F, 0x60, 0x81, 0x60, 0x81, 0x10, 0x0E
.db 0x60, 0x00, 0x10, 0x0E, 0x60, 0x81, 0x10, 0x0E, 0x00, 0x0C, 0x10, 0x0E, 0x00, 0x0C, 0x30, 0x03
.db 0x60, 0x81, 0x00, 0x0C, 0x70, 0x8F, 0x10, 0x0E, 0x00, 0x81, 0x10, 0x0E, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x30, 0x8D, 0x60, 0x0E, 0x10, 0x0F, 0x10, 0x8D, 0x10, 0x0F, 0x10, 0x08, 0x00, 0x81
.db 0x60, 0x81, 0x30, 0x0F, 0x00, 0x06, 0x60, 0x81, 0x30, 0x0F, 0x60, 0x81, 0x60, 0x81, 0x10, 0x0E
.db 0x60, 0x0E, 0x10, 0x8D, 0x60, 0x00, 0x30, 0x0F, 0x00, 0x07, 0x30, 0x8D, 0x00, 0x0C, 0x30, 0x03
.db 0x60, 0x81, 0x00, 0x0C, 0x70, 0x8F, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x0C, 0x00, 0x00, 0x70, 0x8F
.db 0x00, 0x00, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x0C
.db 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x06, 0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x03
.db 0x00, 0x00, 0x00, 0x00, 0x30, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x60, 0x00, 0x00, 0x81, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x10, 0x08, 0x00, 0x00, 0x00, 0x07, 0x00, 0x0C, 0x30, 0x08, 0x00, 0x00, 0x00, 0x00
.db 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F, 0x70, 0x8F
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF0, 0xCF
.db 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x0E
.db 0x00, 0x00, 0x00, 0x00, 0x10, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x60, 0x00, 0x00, 0x81, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.db 0x00, 0x00, 0x70, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.endif
